-- FruitEase - 凉果深加工企业信息化管理系统数据库脚本
-- Version: 1.0
-- Target DBMS: MySQL 8.0
-- Encoding: utf8mb4
-- 删除已存在的表（方便重复执行）
DROP TABLE IF EXISTS `activity_log`;

DROP TABLE IF EXISTS `role_permissions`;

-- 简化，暂不创建
DROP TABLE IF EXISTS `permissions`;

-- 简化，暂不创建
DROP TABLE IF EXISTS `users`;

DROP TABLE IF EXISTS `roles`;

DROP TABLE IF EXISTS `qc_finished_goods_tests`;

DROP TABLE IF EXISTS `shipments`;

DROP TABLE IF EXISTS `carriers`;

DROP TABLE IF EXISTS `sales_order_items`;

DROP TABLE IF EXISTS `sales_orders`;

DROP TABLE IF EXISTS `sales_channels`;

DROP TABLE IF EXISTS `customers`;

DROP TABLE IF EXISTS `production_batches`;

DROP TABLE IF EXISTS `production_plans`;

DROP TABLE IF EXISTS `equipment`;

DROP TABLE IF EXISTS `inventory`;

DROP TABLE IF EXISTS `storage_locations`;

DROP TABLE IF EXISTS `material_receiving`;

DROP TABLE IF EXISTS `purchase_order_items`;

DROP TABLE IF EXISTS `purchase_orders`;

DROP TABLE IF EXISTS `products`;

DROP TABLE IF EXISTS `suppliers`;

-- 1. 供应链与原料管理 (Supply Chain & Raw Material Management)
-- 供应商表
CREATE TABLE `suppliers` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '供应商ID',
  `name` VARCHAR(100) NOT NULL COMMENT '供应商名称',
  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
  `address` VARCHAR(255) DEFAULT NULL COMMENT '地址',
  `rating` TINYINT UNSIGNED DEFAULT NULL COMMENT '供应商评级 (例如 1-5)',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_supplier_name` (`name`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '供应商信息表';

INSERT INTO
  `suppliers` (
    `name`,
    `contact_person`,
    `phone`,
    `address`,
    `rating`
  )
VALUES
  ('阳光果园', '王强', '13812345678', '广东市阳光区果园路1号', 5),
  (
    '丰收农场有限公司',
    '李娜',
    '13987654321',
    '福建省丰收县农场路88号',
    4
  ),
  (
    '绿源农业合作社',
    '张伟',
    '13711223344',
    '广西壮族自治区绿源镇合作路15号',
    4
  ),
  ('鲜果贸易行', '赵敏', '13655447788', '海南省鲜果市贸易街20号', 3);

-- 产品表 (包含原料、半成品、成品)
CREATE TABLE `products` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '产品ID',
  `name` VARCHAR(100) NOT NULL COMMENT '产品名称',
  `description` TEXT DEFAULT NULL COMMENT '产品描述',
  `type` ENUM('raw', 'semi-finished', 'finished') NOT NULL COMMENT '产品类型: raw-原料, semi-finished-半成品, finished-成品',
  `unit` VARCHAR(20) NOT NULL COMMENT '单位 (例如: 公斤, 吨, 袋, 盒)',
  `specification` VARCHAR(100) DEFAULT NULL COMMENT '规格型号',
  `shelf_life_days` INT UNSIGNED DEFAULT NULL COMMENT '保质期 (天)',
  `standard_price` DECIMAL(10, 2) DEFAULT NULL COMMENT '标准售价 (成品)',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_product_name_type` (`name`, `type`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '产品信息表 (原料, 半成品, 成品)';

INSERT INTO
  `products` (
    `name`,
    `description`,
    `type`,
    `unit`,
    `specification`,
    `shelf_life_days`
  )
VALUES
  ('新鲜芒果', '一级凯特芒果', 'raw', '公斤', '单果重300g+', NULL),
  ('新鲜李子', '优质三华李', 'raw', '公斤', '一级果', NULL),
  (
    '盐渍芒果胚',
    '用于芒果干加工的半成品',
    'semi-finished',
    '公斤',
    '沥干含盐量5%',
    90
  ),
  ('芒果干', '风味芒果干成品', 'finished', '袋', '100g装', 180),
  ('冰糖李', '甜味李子凉果', 'finished', '盒', '250g装', 120),
  ('白砂糖', '一级白砂糖', 'raw', '袋', '50kg', 730),
  (
    '食品添加剂A',
    '符合国标GB2760',
    'raw',
    '公斤',
    '纯度99%',
    365
  ),
  ('包装袋', '芒果干包装袋', 'raw', '个', '100g规格', NULL);

-- 采购订单表
CREATE TABLE `purchase_orders` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '采购订单ID',
  `order_number` VARCHAR(50) NOT NULL COMMENT '订单编号',
  `supplier_id` INT UNSIGNED NOT NULL COMMENT '供应商ID',
  `order_date` DATE NOT NULL COMMENT '订单日期',
  `expected_delivery_date` DATE DEFAULT NULL COMMENT '预计到货日期',
  `total_amount` DECIMAL(12, 2) DEFAULT NULL COMMENT '订单总金额',
  `status` ENUM(
    'pending',
    'approved',
    'ordered',
    'partially_received',
    'received',
    'cancelled'
  ) NOT NULL DEFAULT 'pending' COMMENT '订单状态',
  `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '创建人ID',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_purchase_order_number` (`order_number`),
  KEY `idx_po_supplier` (`supplier_id`),
  KEY `idx_po_status` (`status`),
  KEY `idx_po_order_date` (`order_date`) -- , FOREIGN KEY (`supplier_id`) REFERENCES `suppliers` (`id`) ON DELETE RESTRICT -- 暂时注释掉，避免插入示例数据时因顺序问题出错
  -- , FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '采购订单主表';

INSERT INTO
  `purchase_orders` (
    `order_number`,
    `supplier_id`,
    `order_date`,
    `expected_delivery_date`,
    `total_amount`,
    `status`
  )
VALUES
  (
    'PO20240715001',
    1,
    '2024-07-15',
    '2024-07-20',
    15000.00,
    'approved'
  ),
  (
    'PO20240716001',
    2,
    '2024-07-16',
    '2024-07-22',
    8500.50,
    'ordered'
  ),
  (
    'PO20240717001',
    1,
    '2024-07-17',
    '2024-07-25',
    5200.00,
    'pending'
  ),
  (
    'PO20240718001',
    3,
    '2024-07-18',
    '2024-07-23',
    20000.00,
    'received'
  );

-- 采购订单项表
CREATE TABLE `purchase_order_items` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '订单项ID',
  `purchase_order_id` INT UNSIGNED NOT NULL COMMENT '采购订单ID',
  `product_id` INT UNSIGNED NOT NULL COMMENT '产品(原料)ID',
  `quantity` DECIMAL(10, 2) NOT NULL COMMENT '采购数量',
  `unit_price` DECIMAL(10, 2) NOT NULL COMMENT '采购单价',
  `item_total_amount` DECIMAL(12, 2) GENERATED ALWAYS AS (`quantity` * `unit_price`) STORED COMMENT '项总金额',
  `received_quantity` DECIMAL(10, 2) DEFAULT 0.00 COMMENT '已接收数量',
  PRIMARY KEY (`id`),
  KEY `idx_poi_order` (`purchase_order_id`),
  KEY `idx_poi_product` (`product_id`) -- , FOREIGN KEY (`purchase_order_id`) REFERENCES `purchase_orders` (`id`) ON DELETE CASCADE
  -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '采购订单明细表';

INSERT INTO
  `purchase_order_items` (
    `purchase_order_id`,
    `product_id`,
    `quantity`,
    `unit_price`,
    `received_quantity`
  )
VALUES
  (1, 1, 1000.00, 15.00, 0.00),
  -- PO20240715001, 新鲜芒果
  (2, 2, 1500.50, 5.67, 0.00),
  -- PO20240716001, 新鲜李子
  (3, 1, 500.00, 10.40, 0.00),
  -- PO20240717001, 新鲜芒果
  (4, 6, 400.00, 50.00, 400.00);

-- PO20240718001, 白砂糖
-- 原料入库与质检表
CREATE TABLE `material_receiving` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '入库ID',
  `purchase_order_item_id` INT UNSIGNED DEFAULT NULL COMMENT '关联采购订单项ID (可选)',
  `product_id` INT UNSIGNED NOT NULL COMMENT '产品(原料)ID',
  `received_date` DATETIME NOT NULL COMMENT '接收日期时间',
  `received_quantity` DECIMAL(10, 2) NOT NULL COMMENT '接收数量',
  `batch_number` VARCHAR(50) DEFAULT NULL COMMENT '原料批次号 (供应商提供或内部生成)',
  `quality_check_result` ENUM('passed', 'failed', 'pending') NOT NULL DEFAULT 'pending' COMMENT '质检结果',
  `inspector_id` INT UNSIGNED DEFAULT NULL COMMENT '检验员ID',
  `inspection_notes` TEXT DEFAULT NULL COMMENT '检验备注',
  `storage_location_id` INT UNSIGNED DEFAULT NULL COMMENT '存放位置ID',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`),
  KEY `idx_mr_product` (`product_id`),
  KEY `idx_mr_poi` (`purchase_order_item_id`),
  KEY `idx_mr_inspector` (`inspector_id`),
  KEY `idx_mr_location` (`storage_location_id`),
  KEY `idx_mr_received_date` (`received_date`) -- , FOREIGN KEY (`purchase_order_item_id`) REFERENCES `purchase_order_items` (`id`) ON DELETE SET NULL
  -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
  -- , FOREIGN KEY (`inspector_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
  -- , FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '原料入库与质检记录表';

INSERT INTO
  `material_receiving` (
    `purchase_order_item_id`,
    `product_id`,
    `received_date`,
    `received_quantity`,
    `batch_number`,
    `quality_check_result`,
    `inspector_id`,
    `storage_location_id`
  )
VALUES
  (
    4,
    6,
    '2024-07-19 10:00:00',
    400.00,
    'SUGAR240719',
    'passed',
    1,
    1
  ),
  -- 关联PO Item 4 (白砂糖)
  (
    NULL,
    1,
    '2024-07-20 09:30:00',
    500.00,
    'MANGO240720A',
    'passed',
    2,
    2
  ),
  -- 无关联PO，直接入库芒果
  (
    NULL,
    2,
    '2024-07-21 14:15:00',
    1000.00,
    'PLUM240721',
    'pending',
    NULL,
    3
  ),
  -- 待检验的李子
  (
    1,
    1,
    '2024-07-21 16:00:00',
    1000.00,
    'MANGO240721B',
    'passed',
    2,
    2
  );

-- 关联PO Item 1 (芒果)
-- 2. 生产加工管理 (Production & Processing Management)
-- 设备表
CREATE TABLE `equipment` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '设备ID',
  `name` VARCHAR(100) NOT NULL COMMENT '设备名称',
  `model` VARCHAR(100) DEFAULT NULL COMMENT '型号',
  `asset_number` VARCHAR(50) UNIQUE DEFAULT NULL COMMENT '资产编号',
  `purchase_date` DATE DEFAULT NULL COMMENT '购置日期',
  `status` ENUM('operational', 'maintenance', 'idle', 'retired') NOT NULL DEFAULT 'idle' COMMENT '设备状态',
  `location` VARCHAR(100) DEFAULT NULL COMMENT '存放地点/车间',
  `last_maintenance_date` DATE DEFAULT NULL COMMENT '上次维护日期',
  `next_maintenance_date` DATE DEFAULT NULL COMMENT '下次维护日期',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `idx_equip_status` (`status`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '生产设备信息表';

INSERT INTO
  `equipment` (
    `name`,
    `model`,
    `asset_number`,
    `purchase_date`,
    `status`,
    `location`,
    `last_maintenance_date`,
    `next_maintenance_date`
  )
VALUES
  (
    '水果清洗机',
    'QX-500',
    'EQ001',
    '2023-01-10',
    'operational',
    '清洗车间',
    '2024-06-15',
    '2024-12-15'
  ),
  (
    '腌制池',
    'YZC-10T',
    'EQ002',
    '2023-01-15',
    'operational',
    '腌制车间',
    '2024-07-01',
    '2025-01-01'
  ),
  (
    '热风烘干机',
    'HG-200',
    'EQ003',
    '2023-02-20',
    'maintenance',
    '烘干车间',
    '2024-07-10',
    '2024-07-25'
  ),
  (
    '自动包装机',
    'BZ-1000',
    'EQ004',
    '2023-03-01',
    'operational',
    '包装车间',
    '2024-05-20',
    '2024-11-20'
  );

-- 生产计划表
CREATE TABLE `production_plans` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '生产计划ID',
  `plan_number` VARCHAR(50) NOT NULL COMMENT '计划编号',
  `product_id` INT UNSIGNED NOT NULL COMMENT '计划生产产品ID (成品或半成品)',
  `quantity_planned` DECIMAL(10, 2) NOT NULL COMMENT '计划数量',
  `plan_date` DATE NOT NULL COMMENT '计划日期',
  `start_date` DATE DEFAULT NULL COMMENT '计划开始日期',
  `end_date` DATE DEFAULT NULL COMMENT '计划完成日期',
  `status` ENUM(
    'planned',
    'in_progress',
    'completed',
    'cancelled'
  ) NOT NULL DEFAULT 'planned' COMMENT '计划状态',
  `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '创建人ID',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_production_plan_number` (`plan_number`),
  KEY `idx_pp_product` (`product_id`),
  KEY `idx_pp_status` (`status`),
  KEY `idx_pp_plan_date` (`plan_date`) -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
  -- , FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '生产计划主表';

INSERT INTO
  `production_plans` (
    `plan_number`,
    `product_id`,
    `quantity_planned`,
    `plan_date`,
    `start_date`,
    `end_date`,
    `status`
  )
VALUES
  (
    'PP20240716001',
    3,
    500.00,
    '2024-07-16',
    '2024-07-22',
    '2024-07-25',
    'planned'
  ),
  -- 盐渍芒果胚
  (
    'PP20240717001',
    4,
    10000.00,
    '2024-07-17',
    '2024-07-26',
    '2024-07-30',
    'planned'
  ),
  -- 芒果干 (袋)
  (
    'PP20240718001',
    5,
    5000.00,
    '2024-07-18',
    '2024-07-23',
    '2024-07-28',
    'in_progress'
  ),
  -- 冰糖李 (盒)
  (
    'PP20240719001',
    4,
    8000.00,
    '2024-07-19',
    '2024-08-01',
    '2024-08-05',
    'planned'
  );

-- 芒果干 (袋)
-- 生产批次表
CREATE TABLE `production_batches` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '生产批次ID',
  `batch_number` VARCHAR(50) NOT NULL COMMENT '生产批次号',
  `production_plan_id` INT UNSIGNED DEFAULT NULL COMMENT '关联生产计划ID (可选)',
  `product_id` INT UNSIGNED NOT NULL COMMENT '生产产品ID (成品或半成品)',
  `quantity_planned` DECIMAL(10, 2) DEFAULT NULL COMMENT '计划生产量',
  `quantity_produced` DECIMAL(10, 2) DEFAULT NULL COMMENT '实际产量',
  `start_time` DATETIME DEFAULT NULL COMMENT '实际开始时间',
  `end_time` DATETIME DEFAULT NULL COMMENT '实际结束时间',
  `status` ENUM(
    'planned',
    'in_progress',
    'completed',
    'quality_check',
    'stocked',
    'cancelled'
  ) NOT NULL DEFAULT 'planned' COMMENT '批次状态',
  `estimated_cost` DECIMAL(12, 2) DEFAULT NULL COMMENT '预计成本',
  `actual_cost` DECIMAL(12, 2) DEFAULT NULL COMMENT '实际成本',
  `notes` TEXT DEFAULT NULL COMMENT '备注',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_production_batch_number` (`batch_number`),
  KEY `idx_pb_plan` (`production_plan_id`),
  KEY `idx_pb_product` (`product_id`),
  KEY `idx_pb_status` (`status`) -- , FOREIGN KEY (`production_plan_id`) REFERENCES `production_plans` (`id`) ON DELETE SET NULL
  -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '生产批次跟踪表';

INSERT INTO
  `production_batches` (
    `batch_number`,
    `production_plan_id`,
    `product_id`,
    `quantity_planned`,
    `quantity_produced`,
    `start_time`,
    `end_time`,
    `status`
  )
VALUES
  (
    'B20240723001',
    3,
    5,
    5000.00,
    NULL,
    '2024-07-23 08:00:00',
    NULL,
    'in_progress'
  ),
  -- 冰糖李, 关联计划3
  (
    'B20240722001',
    1,
    3,
    500.00,
    495.50,
    '2024-07-22 09:00:00',
    '2024-07-25 17:00:00',
    'completed'
  ),
  -- 盐渍芒果胚, 关联计划1
  (
    'B20240726001',
    2,
    4,
    10000.00,
    NULL,
    NULL,
    NULL,
    'planned'
  ),
  -- 芒果干, 关联计划2
  (
    'B20240720001',
    NULL,
    3,
    200.00,
    198.00,
    '2024-07-20 10:00:00',
    '2024-07-22 16:30:00',
    'quality_check'
  );

-- 盐渍芒果胚, 无计划关联
-- 3. 质量控制与食品安全 (Quality Control & Food Safety)
-- 成品检验表
CREATE TABLE `qc_finished_goods_tests` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '检验ID',
  `production_batch_id` INT UNSIGNED NOT NULL COMMENT '关联生产批次ID',
  `product_id` INT UNSIGNED NOT NULL COMMENT '检验产品ID',
  `test_name` VARCHAR(100) NOT NULL COMMENT '检验项目 (例如: 口感, 色泽, 水分含量)',
  `test_standard` VARCHAR(255) DEFAULT NULL COMMENT '检验标准',
  `test_result_value` VARCHAR(100) DEFAULT NULL COMMENT '检验结果值',
  `result` ENUM('passed', 'failed') NOT NULL COMMENT '检验结论: passed-合格, failed-不合格',
  `test_date` DATETIME NOT NULL COMMENT '检验日期时间',
  `tester_id` INT UNSIGNED DEFAULT NULL COMMENT '检验员ID',
  `notes` TEXT DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  KEY `idx_qc_batch` (`production_batch_id`),
  KEY `idx_qc_product` (`product_id`),
  KEY `idx_qc_tester` (`tester_id`),
  KEY `idx_qc_test_date` (`test_date`) -- , FOREIGN KEY (`production_batch_id`) REFERENCES `production_batches` (`id`) ON DELETE CASCADE
  -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
  -- , FOREIGN KEY (`tester_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '成品质量检验记录表';

INSERT INTO
  `qc_finished_goods_tests` (
    `production_batch_id`,
    `product_id`,
    `test_name`,
    `test_standard`,
    `test_result_value`,
    `result`,
    `test_date`,
    `tester_id`
  )
VALUES
  (
    4,
    3,
    '含盐量',
    '4.5% - 5.5%',
    '5.1%',
    'passed',
    '2024-07-23 09:00:00',
    2
  ),
  -- B20240720001 (盐渍芒果胚)
  (
    4,
    3,
    '外观',
    '色泽均匀，无杂质',
    '符合',
    'passed',
    '2024-07-23 09:15:00',
    2
  ),
  (
    2,
    3,
    '含盐量',
    '4.5% - 5.5%',
    '5.0%',
    'passed',
    '2024-07-26 10:00:00',
    3
  ),
  -- B20240722001 (盐渍芒果胚)
  (
    2,
    3,
    '外观',
    '色泽均匀，无杂质',
    '符合',
    'passed',
    '2024-07-26 10:15:00',
    3
  );

-- 4. 库存管理 (Inventory Management)
-- 存储位置表 (仓库/库位)
CREATE TABLE `storage_locations` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '位置ID',
  `name` VARCHAR(100) NOT NULL COMMENT '位置名称 (例如: A仓库, B区01架)',
  `type` ENUM('warehouse', 'area', 'shelf', 'bin') NOT NULL DEFAULT 'warehouse' COMMENT '位置类型',
  `parent_location_id` INT UNSIGNED DEFAULT NULL COMMENT '上级位置ID',
  `temperature_controlled` BOOLEAN DEFAULT FALSE COMMENT '是否温控',
  `humidity_controlled` BOOLEAN DEFAULT FALSE COMMENT '是否湿控',
  `capacity` DECIMAL(10, 2) DEFAULT NULL COMMENT '容量 (可选)',
  `capacity_unit` VARCHAR(20) DEFAULT NULL COMMENT '容量单位 (可选)',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_location_name` (`name`),
  KEY `idx_sl_parent` (`parent_location_id`) -- , FOREIGN KEY (`parent_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '仓库及库位信息表';

INSERT INTO
  `storage_locations` (
    `name`,
    `type`,
    `parent_location_id`,
    `temperature_controlled`,
    `humidity_controlled`
  )
VALUES
  ('原料仓-常温', 'warehouse', NULL, FALSE, FALSE),
  ('原料仓-冷藏', 'warehouse', NULL, TRUE, FALSE),
  ('半成品仓', 'warehouse', NULL, TRUE, TRUE),
  ('成品仓', 'warehouse', NULL, FALSE, FALSE);

-- 库存概览表 (按产品和位置汇总)
CREATE TABLE `inventory` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '库存ID',
  `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
  `storage_location_id` INT UNSIGNED NOT NULL COMMENT '存储位置ID',
  `quantity_on_hand` DECIMAL(12, 4) NOT NULL DEFAULT 0.0000 COMMENT '当前库存数量',
  `unit` VARCHAR(20) NOT NULL COMMENT '库存单位 (冗余自products表)',
  `low_stock_threshold` DECIMAL(10, 2) DEFAULT NULL COMMENT '低库存预警阈值',
  `last_updated` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_inventory_product_location` (`product_id`, `storage_location_id`),
  KEY `idx_inv_product` (`product_id`),
  KEY `idx_inv_location` (`storage_location_id`) -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE CASCADE
  -- , FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '库存信息表 (按产品和位置汇总)';

INSERT INTO
  `inventory` (
    `product_id`,
    `storage_location_id`,
    `quantity_on_hand`,
    `unit`,
    `low_stock_threshold`
  )
VALUES
  (1, 2, 1500.00, '公斤', 500.00),
  -- 新鲜芒果 在 冷藏库
  (2, 2, 1000.00, '公斤', 300.00),
  -- 新鲜李子 在 冷藏库
  (6, 1, 400.00, '袋', 50.00),
  -- 白砂糖 在 常温库
  (3, 3, 693.50, '公斤', 100.00);

-- 盐渍芒果胚 在 半成品仓 (来自批次B20240722001和B20240720001)
-- 添加芒果干库存记录
INSERT INTO
  `inventory` (
    `product_id`,
    `storage_location_id`,
    `quantity_on_hand`,
    `unit`,
    `low_stock_threshold`
  )
VALUES
  (4, 4, 500.00, '袋', 100.00);

-- 芒果干 在 成品仓
-- 添加冰糖李库存记录
INSERT INTO
  `inventory` (
    `product_id`,
    `storage_location_id`,
    `quantity_on_hand`,
    `unit`,
    `low_stock_threshold`
  )
VALUES
  (5, 4, 300.00, '盒', 50.00);

-- 冰糖李 在 成品仓
-- 5. 订单与销售管理 (Order & Sales Management)
-- 客户表
CREATE TABLE `customers` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '客户ID',
  `name` VARCHAR(100) NOT NULL COMMENT '客户名称',
  `type` ENUM(
    'wholesale',
    'retail',
    'distributor',
    'ecommerce'
  ) NOT NULL COMMENT '客户类型',
  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
  `email` VARCHAR(100) UNIQUE DEFAULT NULL COMMENT '邮箱',
  `address` VARCHAR(255) DEFAULT NULL COMMENT '地址',
  `region` VARCHAR(50) DEFAULT NULL COMMENT '区域',
  `join_date` DATE DEFAULT NULL COMMENT '成为客户日期',
  `credit_limit` DECIMAL(12, 2) DEFAULT NULL COMMENT '信用额度',
  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否启用',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `idx_cust_name` (`name`),
  KEY `idx_cust_type` (`type`),
  KEY `idx_cust_region` (`region`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '客户信息表';

INSERT INTO
  `customers` (
    `name`,
    `type`,
    `contact_person`,
    `phone`,
    `email`,
    `address`,
    `region`,
    `join_date`
  )
VALUES
  (
    '华南食品批发市场A栋3号',
    'wholesale',
    '刘经理',
    '13511112222',
    'liujingli@huanan.com',
    '广东省广州市白云区市场路1号',
    '华南',
    '2023-05-10'
  ),
  (
    '美味零食连锁超市',
    'retail',
    '采购部张三',
    '020-88889999',
    'caigou@meiwei.com',
    '上海市浦东新区世纪大道100号',
    '华东',
    '2023-08-15'
  ),
  (
    '电商平台旗舰店',
    'ecommerce',
    '店长小李',
    '13788889999',
    'fruitease@shop.com',
    '线上地址',
    '全国',
    '2024-01-01'
  ),
  (
    '西北区域代理商',
    'distributor',
    '马先生',
    '13977778888',
    'maxiansheng@xibei.com',
    '陕西省西安市高新区科技路5号',
    '西北',
    '2023-11-20'
  );

-- 销售渠道表
CREATE TABLE `sales_channels` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '渠道ID',
  `name` VARCHAR(50) NOT NULL COMMENT '渠道名称 (例如: B2B批发, 电商平台, 线下经销)',
  `description` VARCHAR(255) DEFAULT NULL COMMENT '渠道描述',
  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否启用',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_channel_name` (`name`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '销售渠道信息表';

INSERT INTO
  `sales_channels` (`name`, `description`)
VALUES
  ('B2B批发', '面向批发客户的渠道'),
  ('电商平台', '如淘宝、京东等线上销售渠道'),
  ('线下经销', '通过各地经销商销售'),
  ('零售直营', '公司直接零售');

-- 销售订单表
CREATE TABLE `sales_orders` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '销售订单ID',
  `order_number` VARCHAR(50) NOT NULL COMMENT '订单编号',
  `customer_id` INT UNSIGNED NOT NULL COMMENT '客户ID',
  `sales_channel_id` INT UNSIGNED DEFAULT NULL COMMENT '销售渠道ID',
  `order_date` DATETIME NOT NULL COMMENT '订单日期时间',
  `required_date` DATE DEFAULT NULL COMMENT '要求交货日期',
  `total_amount` DECIMAL(12, 2) DEFAULT NULL COMMENT '订单总金额',
  `status` ENUM(
    'draft',
    'confirmed',
    'processing',
    'partially_shipped',
    'shipped',
    'delivered',
    'cancelled'
  ) NOT NULL DEFAULT 'draft' COMMENT '订单状态',
  `shipping_address` VARCHAR(255) DEFAULT NULL COMMENT '收货地址',
  `notes` TEXT DEFAULT NULL COMMENT '订单备注',
  `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '创建人ID',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_sales_order_number` (`order_number`),
  KEY `idx_so_customer` (`customer_id`),
  KEY `idx_so_channel` (`sales_channel_id`),
  KEY `idx_so_status` (`status`),
  KEY `idx_so_order_date` (`order_date`) -- , FOREIGN KEY (`customer_id`) REFERENCES `customers` (`id`) ON DELETE RESTRICT
  -- , FOREIGN KEY (`sales_channel_id`) REFERENCES `sales_channels` (`id`) ON DELETE SET NULL
  -- , FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '销售订单主表';

INSERT INTO
  `sales_orders` (
    `order_number`,
    `customer_id`,
    `sales_channel_id`,
    `order_date`,
    `required_date`,
    `total_amount`,
    `status`,
    `shipping_address`
  )
VALUES
  (
    'SO20240720001',
    1,
    1,
    '2024-07-20 10:00:00',
    '2024-07-28',
    5800.00,
    'confirmed',
    '广东省广州市白云区市场路1号 华南食品批发市场A栋3号'
  ),
  (
    'SO20240721001',
    3,
    2,
    '2024-07-21 11:30:00',
    '2024-07-26',
    125.50,
    'processing',
    '上海市浦东新区XX路XX号 张三 收'
  ),
  (
    'SO20240722001',
    4,
    3,
    '2024-07-22 14:00:00',
    '2024-08-05',
    15000.00,
    'confirmed',
    '陕西省西安市高新区科技路5号'
  ),
  (
    'SO20240723001',
    2,
    4,
    '2024-07-23 09:45:00',
    '2024-07-30',
    880.00,
    'draft',
    '上海市浦东新区世纪大道100号 美味零食连锁超市总仓'
  );

-- 销售订单项表
CREATE TABLE `sales_order_items` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '订单项ID',
  `sales_order_id` INT UNSIGNED NOT NULL COMMENT '销售订单ID',
  `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID (成品)',
  `quantity` DECIMAL(10, 2) NOT NULL COMMENT '销售数量',
  `unit_price` DECIMAL(10, 2) NOT NULL COMMENT '销售单价',
  `discount_rate` DECIMAL(5, 4) DEFAULT 0.0000 COMMENT '折扣率 (例如 0.1 表示 10% off)',
  `item_total_amount` DECIMAL(12, 2) GENERATED ALWAYS AS (
    `quantity` * `unit_price` * (1 - `discount_rate`)
  ) STORED COMMENT '项总金额 (扣除折扣后)',
  `shipped_quantity` DECIMAL(10, 2) DEFAULT 0.00 COMMENT '已发货数量',
  PRIMARY KEY (`id`),
  KEY `idx_soi_order` (`sales_order_id`),
  KEY `idx_soi_product` (`product_id`) -- , FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE CASCADE
  -- , FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '销售订单明细表';

INSERT INTO
  `sales_order_items` (
    `sales_order_id`,
    `product_id`,
    `quantity`,
    `unit_price`,
    `discount_rate`
  )
VALUES
  (1, 4, 200.00, 29.00, 0.00),
  -- SO20240720001, 芒果干
  (2, 5, 5.00, 25.10, 0.00),
  -- SO20240721001, 冰糖李
  (3, 4, 500.00, 30.00, 0.05),
  -- SO20240722001, 芒果干 (5% discount)
  (4, 5, 35.20, 25.00, 0.00);

-- SO20240723001, 冰糖李
-- 7. 物流与配送管理 (Logistics & Distribution Management)
-- 物流公司表
CREATE TABLE `carriers` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '物流公司ID',
  `name` VARCHAR(100) NOT NULL COMMENT '公司名称',
  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
  `service_type` VARCHAR(50) DEFAULT NULL COMMENT '服务类型 (例如: 快递, 专线物流, 冷链)',
  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否合作',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_carrier_name` (`name`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '物流承运商信息表';

INSERT INTO
  `carriers` (
    `name`,
    `contact_person`,
    `phone`,
    `service_type`
  )
VALUES
  ('顺丰速运', '张经理', '95338', '快递, 冷链'),
  ('德邦物流', '李主管', '95353', '专线物流, 大件运输'),
  ('京东物流', '王先生', '950616', '快递, 仓配一体'),
  ('本地冷链专线', '赵师傅', '13800138000', '冷链专线');

-- 发货表
CREATE TABLE `shipments` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '发货ID',
  `shipment_number` VARCHAR(50) NOT NULL COMMENT '发货单号',
  `sales_order_id` INT UNSIGNED NOT NULL COMMENT '关联销售订单ID',
  `carrier_id` INT UNSIGNED DEFAULT NULL COMMENT '承运商ID',
  `tracking_number` VARCHAR(100) DEFAULT NULL COMMENT '物流单号',
  `shipment_date` DATETIME NOT NULL COMMENT '发货日期时间',
  `estimated_delivery_date` DATE DEFAULT NULL COMMENT '预计送达日期',
  `actual_delivery_date` DATETIME DEFAULT NULL COMMENT '实际送达日期时间',
  `shipping_cost` DECIMAL(10, 2) DEFAULT NULL COMMENT '物流费用',
  `status` ENUM(
    'pending',
    'ready_to_ship',
    'shipped',
    'in_transit',
    'delivered',
    'failed',
    'cancelled'
  ) NOT NULL DEFAULT 'pending' COMMENT '发货状态',
  `notes` TEXT DEFAULT NULL COMMENT '备注',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_shipment_number` (`shipment_number`),
  KEY `idx_ship_order` (`sales_order_id`),
  KEY `idx_ship_carrier` (`carrier_id`),
  KEY `idx_ship_status` (`status`),
  KEY `idx_ship_date` (`shipment_date`) -- , FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE RESTRICT
  -- , FOREIGN KEY (`carrier_id`) REFERENCES `carriers` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '发货记录表';

INSERT INTO
  `shipments` (
    `shipment_number`,
    `sales_order_id`,
    `carrier_id`,
    `tracking_number`,
    `shipment_date`,
    `estimated_delivery_date`,
    `shipping_cost`,
    `status`
  )
VALUES
  (
    'SHP20240725001',
    1,
    2,
    'DB123456789',
    '2024-07-25 16:00:00',
    '2024-07-28',
    150.00,
    'shipped'
  ),
  -- SO20240720001 发货
  (
    'SHP20240726001',
    2,
    1,
    'SF987654321',
    '2024-07-26 10:30:00',
    '2024-07-27',
    15.50,
    'in_transit'
  ),
  -- SO20240721001 发货
  (
    'SHP20240728001',
    3,
    4,
    'LLZ998877',
    '2024-07-28 09:00:00',
    '2024-08-01',
    800.00,
    'ready_to_ship'
  ),
  -- SO20240722001 待发货
  (
    'SHP20240729001',
    1,
    2,
    'DB112233445',
    '2024-07-29 11:00:00',
    '2024-08-01',
    50.00,
    'pending'
  );

-- SO20240720001 部分发货（示例）
-- 10. 系统设置 (System Settings)
-- 角色表
CREATE TABLE `roles` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '角色ID',
  `name` VARCHAR(50) NOT NULL COMMENT '角色名称 (例如: 管理员, 采购员, 生产主管)',
  `description` VARCHAR(255) DEFAULT NULL COMMENT '角色描述',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_role_name` (`name`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '用户角色表';

INSERT INTO
  `roles` (`name`, `description`)
VALUES
  ('管理员', '拥有系统所有权限'),
  ('采购员', '负责采购管理模块操作'),
  ('生产主管', '负责生产计划、执行与监控'),
  ('销售人员', '负责销售订单、客户管理');

-- 用户表
CREATE TABLE `users` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '用户ID',
  `username` VARCHAR(50) NOT NULL COMMENT '用户名',
  `password_hash` VARCHAR(255) NOT NULL COMMENT '密码哈希值',
  `full_name` VARCHAR(50) DEFAULT NULL COMMENT '姓名',
  `email` VARCHAR(100) UNIQUE DEFAULT NULL COMMENT '邮箱',
  `phone` VARCHAR(20) UNIQUE DEFAULT NULL COMMENT '手机号',
  `role_id` INT UNSIGNED NOT NULL COMMENT '角色ID',
  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否启用',
  `last_login_at` TIMESTAMP NULL DEFAULT NULL COMMENT '最后登录时间',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_username` (`username`),
  KEY `idx_user_role` (`role_id`),
  KEY `idx_user_status` (`is_active`) -- , FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '用户信息表';

INSERT INTO
  `users` (
    `username`,
    `password_hash`,
    `full_name`,
    `email`,
    `phone`,
    `role_id`,
    `is_active`
  )
VALUES
  (
    'admin',
    '$2y$10$7DOsBGGPYLrOYejhj07BbOmC4pq1gFp0qImybWTD4iX3pVnaACUMa',
    '系统管理员',
    'admin@fruitease.com',
    '18800000001',
    1,
    TRUE
  ),
  -- 用户名：admin 密码：admin
  (
    'purchaser01',
    '$2y$10$ExampleHashValuePurch01',
    '张采购',
    'zhangcg@fruitease.com',
    '18800000002',
    2,
    TRUE
  ),
  (
    'producer01',
    '$2y$10$ExampleHashValueProd01',
    '李主管',
    'lizg@fruitease.com',
    '18800000003',
    3,
    TRUE
  ),
  (
    'sales01',
    '$2y$10$ExampleHashValueSales01',
    '王销售',
    'wangsx@fruitease.com',
    '18800000004',
    4,
    FALSE
  );

-- 操作日志表
CREATE TABLE `activity_log` (
  `id` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '日志ID',
  `user_id` INT UNSIGNED DEFAULT NULL COMMENT '操作用户ID',
  `username` VARCHAR(50) DEFAULT NULL COMMENT '操作用户名 (冗余)',
  `action` VARCHAR(255) NOT NULL COMMENT '执行的操作描述 (例如: 创建采购订单, 审核生产计划)',
  `target_type` VARCHAR(50) DEFAULT NULL COMMENT '操作对象类型 (例如: purchase_order, product)',
  `target_id` INT UNSIGNED DEFAULT NULL COMMENT '操作对象ID',
  `details` TEXT DEFAULT NULL COMMENT '操作详情 (例如: JSON格式的变更内容)',
  `ip_address` VARCHAR(45) DEFAULT NULL COMMENT '操作者IP地址',
  `timestamp` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
  PRIMARY KEY (`id`),
  KEY `idx_log_user` (`user_id`),
  KEY `idx_log_target` (`target_type`, `target_id`),
  KEY `idx_log_timestamp` (`timestamp`) -- , FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '系统操作日志表';

INSERT INTO
  `activity_log` (
    `user_id`,
    `username`,
    `action`,
    `target_type`,
    `target_id`,
    `details`,
    `ip_address`
  )
VALUES
  (
    1,
    'admin',
    '用户登录',
    'user',
    1,
    NULL,
    '192.168.1.100'
  ),
  (
    2,
    'purchaser01',
    '创建采购订单',
    'purchase_order',
    3,
    '{"order_number": "PO20240717001", "supplier_id": 1}',
    '192.168.1.101'
  ),
  (
    3,
    'producer01',
    '更新生产批次状态',
    'production_batch',
    1,
    '{"old_status": "planned", "new_status": "in_progress"}',
    '192.168.1.102'
  ),
  (
    1,
    'admin',
    '禁用用户',
    'user',
    4,
    '{"username": "sales01", "is_active": false}',
    '192.168.1.100'
  );

-- 补全外键约束 (放在最后，确保所有表已创建)
ALTER TABLE
  `purchase_orders`
ADD
  CONSTRAINT `fk_po_supplier` FOREIGN KEY (`supplier_id`) REFERENCES `suppliers` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `purchase_orders`
ADD
  CONSTRAINT `fk_po_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `purchase_order_items`
ADD
  CONSTRAINT `fk_poi_order` FOREIGN KEY (`purchase_order_id`) REFERENCES `purchase_orders` (`id`) ON DELETE CASCADE;

ALTER TABLE
  `purchase_order_items`
ADD
  CONSTRAINT `fk_poi_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `material_receiving`
ADD
  CONSTRAINT `fk_mr_poi` FOREIGN KEY (`purchase_order_item_id`) REFERENCES `purchase_order_items` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `material_receiving`
ADD
  CONSTRAINT `fk_mr_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `material_receiving`
ADD
  CONSTRAINT `fk_mr_inspector` FOREIGN KEY (`inspector_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `material_receiving`
ADD
  CONSTRAINT `fk_mr_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `production_plans`
ADD
  CONSTRAINT `fk_pp_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `production_plans`
ADD
  CONSTRAINT `fk_pp_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `production_batches`
ADD
  CONSTRAINT `fk_pb_plan` FOREIGN KEY (`production_plan_id`) REFERENCES `production_plans` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `production_batches`
ADD
  CONSTRAINT `fk_pb_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `qc_finished_goods_tests`
ADD
  CONSTRAINT `fk_qc_batch` FOREIGN KEY (`production_batch_id`) REFERENCES `production_batches` (`id`) ON DELETE CASCADE;

ALTER TABLE
  `qc_finished_goods_tests`
ADD
  CONSTRAINT `fk_qc_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `qc_finished_goods_tests`
ADD
  CONSTRAINT `fk_qc_tester` FOREIGN KEY (`tester_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `storage_locations`
ADD
  CONSTRAINT `fk_sl_parent` FOREIGN KEY (`parent_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `inventory`
ADD
  CONSTRAINT `fk_inv_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE CASCADE;

ALTER TABLE
  `inventory`
ADD
  CONSTRAINT `fk_inv_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `sales_orders`
ADD
  CONSTRAINT `fk_so_customer` FOREIGN KEY (`customer_id`) REFERENCES `customers` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `sales_orders`
ADD
  CONSTRAINT `fk_so_channel` FOREIGN KEY (`sales_channel_id`) REFERENCES `sales_channels` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `sales_orders`
ADD
  CONSTRAINT `fk_so_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `sales_order_items`
ADD
  CONSTRAINT `fk_soi_order` FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE CASCADE;

ALTER TABLE
  `sales_order_items`
ADD
  CONSTRAINT `fk_soi_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `shipments`
ADD
  CONSTRAINT `fk_ship_order` FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `shipments`
ADD
  CONSTRAINT `fk_ship_carrier` FOREIGN KEY (`carrier_id`) REFERENCES `carriers` (`id`) ON DELETE
SET
  NULL;

ALTER TABLE
  `users`
ADD
  CONSTRAINT `fk_user_role` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE RESTRICT;

ALTER TABLE
  `activity_log`
ADD
  CONSTRAINT `fk_log_user` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE
SET
  NULL;

-- 库存盘点表
CREATE TABLE IF NOT EXISTS `inventory_checks` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '盘点ID',
  `batch_number` VARCHAR(50) NOT NULL COMMENT '盘点批次号',
  `check_date` DATE NOT NULL COMMENT '盘点日期',
  `storage_location_id` INT UNSIGNED NOT NULL COMMENT '仓库位置ID',
  `notes` TEXT DEFAULT NULL COMMENT '盘点备注',
  `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '盘点人员ID',
  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_inventory_check_batch_number` (`batch_number`),
  KEY `idx_inventory_check_location` (`storage_location_id`),
  KEY `idx_inventory_check_user` (`created_by_user_id`),
  KEY `idx_inventory_check_date` (`check_date`),
  CONSTRAINT `fk_inventory_check_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT,
  CONSTRAINT `fk_inventory_check_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE
  SET
    NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '库存盘点主表';

-- 库存盘点明细表
CREATE TABLE IF NOT EXISTS `inventory_check_items` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '盘点明细ID',
  `inventory_check_id` INT UNSIGNED NOT NULL COMMENT '关联盘点ID',
  `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
  `system_quantity` DECIMAL(10, 2) NOT NULL COMMENT '系统库存数量',
  `actual_quantity` DECIMAL(10, 2) NOT NULL COMMENT '实际盘点数量',
  `difference` DECIMAL(10, 2) GENERATED ALWAYS AS (`actual_quantity` - `system_quantity`) STORED COMMENT '差异数量',
  `notes` TEXT DEFAULT NULL COMMENT '明细备注',
  PRIMARY KEY (`id`),
  KEY `idx_inventory_check_item_check` (`inventory_check_id`),
  KEY `idx_inventory_check_item_product` (`product_id`),
  KEY `idx_inventory_check_item_difference` (`difference`),
  CONSTRAINT `fk_inventory_check_item_check` FOREIGN KEY (`inventory_check_id`) REFERENCES `inventory_checks` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fk_inventory_check_item_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '库存盘点明细表';

-- 插入初始库存盘点数据
INSERT INTO
  `inventory_checks` (
    `batch_number`,
    `check_date`,
    `storage_location_id`,
    `notes`,
    `created_by_user_id`
  )
VALUES
  (
    'INV-CHECK-20250417004325',
    '2025-04-17',
    3,
    '半成品库季度盘点',
    1
  );

-- 插入示例盘点明细记录
INSERT INTO
  `inventory_check_items` (
    `inventory_check_id`,
    `product_id`,
    `system_quantity`,
    `actual_quantity`,
    `notes`
  )
VALUES
  (1, 5, 100.00, 100.00, '无差异');

-- End of script