<?php

/**
 * 市场营销管理
 * 用于管理市场营销活动、促销活动和分销管理
 */

session_start();
require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 设置页面标题
$page_title = "市场营销";

// 初始化变量
$success = '';
$error = '';

// 获取筛选参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$type = isset($_GET['type']) ? $_GET['type'] : '';
$status = isset($_GET['status']) ? $_GET['status'] : '';
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : '';

// 创建营销活动表
try {
    // 检查营销活动表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'marketing_campaigns'");
    if (!$stmt->rowCount()) {
        // 创建营销活动表
        $pdo->exec("
            CREATE TABLE `marketing_campaigns` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '活动ID',
              `name` VARCHAR(100) NOT NULL COMMENT '活动名称',
              `type` ENUM('promotion', 'discount', 'event', 'social_media', 'new_product') NOT NULL COMMENT '活动类型',
              `description` TEXT DEFAULT NULL COMMENT '活动描述',
              `start_date` DATE NOT NULL COMMENT '开始日期',
              `end_date` DATE DEFAULT NULL COMMENT '结束日期',
              `target_audience` VARCHAR(100) DEFAULT NULL COMMENT '目标受众',
              `budget` DECIMAL(10, 2) DEFAULT NULL COMMENT '预算',
              `status` ENUM('planned', 'active', 'completed', 'cancelled') NOT NULL DEFAULT 'planned' COMMENT '状态',
              `kpi` VARCHAR(255) DEFAULT NULL COMMENT '关键绩效指标',
              `results` TEXT DEFAULT NULL COMMENT '活动结果',
              `created_by_user_id` INT UNSIGNED NOT NULL COMMENT '创建人ID',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              KEY `idx_campaign_type` (`type`),
              KEY `idx_campaign_status` (`status`),
              KEY `idx_campaign_dates` (`start_date`, `end_date`)
            ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '营销活动表'
        ");

        // 插入示例数据
        $pdo->exec("
            INSERT INTO
              `marketing_campaigns` (
                `name`,
                `type`,
                `description`,
                `start_date`,
                `end_date`,
                `target_audience`,
                `budget`,
                `status`,
                `kpi`,
                `created_by_user_id`
              )
            VALUES
              (
                '2024新品上市促销',
                'new_product',
                '所有新上市产品8折优惠',
                '2024-01-15',
                '2024-02-15',
                '所有客户',
                5000.00,
                'completed',
                '销售额提升20%',
                1
              ),
              (
                '批发客户满额赠礼',
                'promotion',
                '批发客户单笔订单满5000元赠送精美礼品',
                '2024-03-01',
                '2024-04-30',
                '批发客户',
                3000.00,
                'active',
                '批发订单数量提升15%',
                1
              ),
              (
                '夏季促销活动',
                'discount',
                '所有夏季产品九折优惠',
                '2024-06-01',
                '2024-08-31',
                '零售和电商客户',
                8000.00,
                'planned',
                '夏季产品销量提升30%',
                1
              )
        ");
        $success = "已创建营销活动表并插入示例数据";
    }

    // 处理添加/编辑营销活动表单提交
    if (isset($_POST['save_campaign'])) {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = trim($_POST['name']);
        $type = $_POST['type'];
        $description = trim($_POST['description']);
        $start_date = $_POST['start_date'];
        $end_date = !empty($_POST['end_date']) ? $_POST['end_date'] : null;
        $target_audience = trim($_POST['target_audience']);
        $budget = !empty($_POST['budget']) ? floatval($_POST['budget']) : null;
        $status = $_POST['status'];
        $kpi = trim($_POST['kpi']);
        $results = trim($_POST['results']);

        // 验证必填字段
        if (empty($name) || empty($type) || empty($start_date) || empty($status)) {
            $error = "活动名称、类型、开始日期和状态为必填项！";
        } else {
            try {
                if ($id > 0) {
                    // 更新营销活动
                    $stmt = $pdo->prepare("
                        UPDATE marketing_campaigns SET 
                            name = ?, 
                            type = ?, 
                            description = ?, 
                            start_date = ?, 
                            end_date = ?, 
                            target_audience = ?, 
                            budget = ?,
                            status = ?,
                            kpi = ?,
                            results = ?
                        WHERE id = ?
                    ");
                    $stmt->execute([
                        $name,
                        $type,
                        $description,
                        $start_date,
                        $end_date,
                        $target_audience,
                        $budget,
                        $status,
                        $kpi,
                        $results,
                        $id
                    ]);
                    $success = "营销活动已更新！";
                } else {
                    // 添加新营销活动
                    $stmt = $pdo->prepare("
                        INSERT INTO marketing_campaigns (
                            name, 
                            type, 
                            description, 
                            start_date, 
                            end_date, 
                            target_audience, 
                            budget,
                            status,
                            kpi,
                            created_by_user_id
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $name,
                        $type,
                        $description,
                        $start_date,
                        $end_date,
                        $target_audience,
                        $budget,
                        $status,
                        $kpi,
                        $_SESSION['user_id']
                    ]);
                    $success = "营销活动已成功添加！";
                }

                // 记录操作日志
                if (isset($_SESSION['user_id']) && isset($_SESSION['username'])) {
                    $action = $id > 0 ? '更新营销活动' : '创建营销活动';
                    $details = json_encode([
                        'id' => $id > 0 ? $id : $pdo->lastInsertId(),
                        'name' => $name,
                        'type' => $type
                    ]);

                    $stmt = $pdo->prepare("
                        INSERT INTO activity_log (
                            user_id, 
                            username, 
                            action, 
                            target_type, 
                            target_id, 
                            details, 
                            ip_address
                        ) VALUES (?, ?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $_SESSION['user_id'],
                        $_SESSION['username'],
                        $action,
                        'marketing_campaign',
                        $id > 0 ? $id : $pdo->lastInsertId(),
                        $details,
                        $_SERVER['REMOTE_ADDR']
                    ]);
                }
            } catch (PDOException $e) {
                $error = "保存营销活动失败：" . $e->getMessage();
            }
        }
    }

    // 构建查询
    $sql = "SELECT * FROM marketing_campaigns WHERE 1=1";
    $params = [];

    if (!empty($search)) {
        $sql .= " AND (name LIKE ? OR description LIKE ? OR target_audience LIKE ?)";
        $search_param = "%$search%";
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
    }

    if (!empty($type)) {
        $sql .= " AND type = ?";
        $params[] = $type;
    }

    if (!empty($status)) {
        $sql .= " AND status = ?";
        $params[] = $status;
    }

    if (!empty($date_range)) {
        if ($date_range == 'current') {
            $sql .= " AND (start_date <= CURRENT_DATE() AND (end_date IS NULL OR end_date >= CURRENT_DATE()))";
        } elseif ($date_range == 'upcoming') {
            $sql .= " AND start_date > CURRENT_DATE()";
        } elseif ($date_range == 'past') {
            $sql .= " AND end_date < CURRENT_DATE()";
        }
    }

    $sql .= " ORDER BY start_date DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $campaigns = $stmt->fetchAll();

    // 获取要编辑的营销活动信息
    $edit_data = null;
    if (isset($_GET['edit']) && $_GET['edit'] > 0) {
        $edit_id = intval($_GET['edit']);
        $stmt = $pdo->prepare("SELECT * FROM marketing_campaigns WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_data = $stmt->fetch();
    }

    // 营销活动类型映射
    $campaign_types = [
        'promotion' => '促销活动',
        'discount' => '折扣活动',
        'event' => '活动/展会',
        'social_media' => '社交媒体活动',
        'new_product' => '新品推广'
    ];

    // 活动状态映射
    $campaign_statuses = [
        'planned' => '计划中',
        'active' => '进行中',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
} catch (PDOException $e) {
    $error = "数据库错误：" . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($page_title) ?> - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="content">
        <h1><?= htmlspecialchars($page_title) ?></h1>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <!-- 筛选与搜索 -->
        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="text" name="search" placeholder="搜索活动名称、描述..." value="<?= htmlspecialchars($search) ?>">

                <select name="type" title="活动类型">
                    <option value="">所有类型</option>
                    <?php foreach ($campaign_types as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $type === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="status" title="活动状态">
                    <option value="">所有状态</option>
                    <?php foreach ($campaign_statuses as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $status === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="date_range" title="日期范围">
                    <option value="">所有日期</option>
                    <option value="current" <?= $date_range === 'current' ? 'selected' : '' ?>>当前活动</option>
                    <option value="upcoming" <?= $date_range === 'upcoming' ? 'selected' : '' ?>>即将开始</option>
                    <option value="past" <?= $date_range === 'past' ? 'selected' : '' ?>>已结束</option>
                </select>

                <button type="submit">搜索</button>
                <button type="button" onclick="location.href='marketing_management.php'" class="btn-secondary">重置</button>
            </form>
        </div>

        <!-- 添加/编辑营销活动表单 -->
        <div class="form-container">
            <h2><?= $edit_data ? '编辑营销活动' : '添加新营销活动' ?></h2>
            <form method="POST" action="">
                <?php if ($edit_data): ?>
                    <input type="hidden" name="id" value="<?= $edit_data['id'] ?>">
                <?php endif; ?>

                <div class="form-group">
                    <label for="name">活动名称 <span class="required">*</span></label>
                    <input type="text" id="name" name="name" value="<?= $edit_data ? htmlspecialchars($edit_data['name']) : '' ?>" required>
                </div>

                <div class="form-group">
                    <label for="type">活动类型 <span class="required">*</span></label>
                    <select id="type" name="type" required>
                        <option value="">-- 请选择 --</option>
                        <?php foreach ($campaign_types as $key => $value): ?>
                            <option value="<?= $key ?>" <?= $edit_data && $edit_data['type'] === $key ? 'selected' : '' ?>><?= $value ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label for="description">活动描述</label>
                    <textarea id="description" name="description" rows="4"><?= $edit_data ? htmlspecialchars($edit_data['description']) : '' ?></textarea>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="start_date">开始日期 <span class="required">*</span></label>
                        <input type="date" id="start_date" name="start_date" value="<?= $edit_data ? $edit_data['start_date'] : date('Y-m-d') ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期</label>
                        <input type="date" id="end_date" name="end_date" value="<?= $edit_data && $edit_data['end_date'] ? $edit_data['end_date'] : '' ?>">
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="target_audience">目标受众</label>
                        <input type="text" id="target_audience" name="target_audience" value="<?= $edit_data ? htmlspecialchars($edit_data['target_audience']) : '' ?>">
                    </div>

                    <div class="form-group">
                        <label for="budget">预算 (¥)</label>
                        <input type="number" id="budget" name="budget" step="0.01" min="0" value="<?= $edit_data && $edit_data['budget'] ? $edit_data['budget'] : '' ?>" placeholder="0.00">
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="status">状态 <span class="required">*</span></label>
                        <select id="status" name="status" required>
                            <?php foreach ($campaign_statuses as $key => $value): ?>
                                <option value="<?= $key ?>" <?= $edit_data && $edit_data['status'] === $key ? 'selected' : ($key === 'planned' && !$edit_data ? 'selected' : '') ?>><?= $value ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="kpi">关键绩效指标</label>
                        <input type="text" id="kpi" name="kpi" value="<?= $edit_data ? htmlspecialchars($edit_data['kpi']) : '' ?>" placeholder="例如：销售额提升20%">
                    </div>
                </div>

                <?php if ($edit_data): ?>
                    <div class="form-group">
                        <label for="results">活动结果</label>
                        <textarea id="results" name="results" rows="4"><?= $edit_data ? htmlspecialchars($edit_data['results']) : '' ?></textarea>
                    </div>
                <?php endif; ?>

                <div class="form-actions">
                    <button type="submit" name="save_campaign" class="btn-primary"><?= $edit_data ? '更新活动' : '添加活动' ?></button>
                    <?php if ($edit_data): ?>
                        <!-- 成功后返回营销活动列表 -->                         
                        <button type="button" onclick="location.href='marketing_management.php'" class="btn-secondary">取消</button>
                    <?php endif; ?>
                </div>
            </form>
        </div>

        <!-- 营销活动列表 -->
        <div class="table-container">
            <h2>营销活动列表</h2>
            <?php if (empty($campaigns)): ?>
                <div class="empty-state">
                    <p>暂无营销活动数据</p>
                </div>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>活动名称</th>
                            <th>类型</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>目标受众</th>
                            <th>预算</th>
                            <th>状态</th>
                            <th>关键绩效指标</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($campaigns as $campaign): ?>
                            <tr class="<?= $campaign['status'] === 'cancelled' ? 'warning-row' : '' ?>">
                                <td><?= htmlspecialchars($campaign['name']) ?></td>
                                <td><?= isset($campaign_types[$campaign['type']]) ? $campaign_types[$campaign['type']] : $campaign['type'] ?></td>
                                <td><?= date('Y-m-d', strtotime($campaign['start_date'])) ?></td>
                                <td><?= $campaign['end_date'] ? date('Y-m-d', strtotime($campaign['end_date'])) : '-' ?></td>
                                <td><?= htmlspecialchars($campaign['target_audience'] ?: '-') ?></td>
                                <td><?= $campaign['budget'] ? '¥' . number_format($campaign['budget'], 2) : '-' ?></td>
                                <td>
                                    <span class="status-tag <?= $campaign['status'] ?>">
                                        <?= $campaign_statuses[$campaign['status']] ?>
                                    </span>
                                </td>
                                <td><?= htmlspecialchars($campaign['kpi'] ?: '-') ?></td>
                                <td>
                                    <a href="?edit=<?= $campaign['id'] ?>" class="btn-edit">编辑</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <style>
        /* 补充样式 */
        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .form-row {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        .search-bar {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-items: center;
        }

        .search-bar input,
        .search-bar select {
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            flex: 1;
        }

        .search-bar button {
            padding: 8px 16px;
            border: none;
            border-radius: 4px;
            background-color: #3498db;
            color: white;
            cursor: pointer;
        }

        .search-bar button.btn-secondary {
            background-color: #6c757d;
        }

        textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            resize: vertical;
        }

        .form-actions {
            display: flex;
            justify-content: flex-start;
            gap: 10px;
            margin-top: 20px;
        }

        .required {
            color: #e74c3c;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 0.85em;
            font-weight: 500;
            color: white;
        }

        .status-tag.planned {
            background-color: #f39c12;
        }

        .status-tag.active {
            background-color: #3498db;
        }

        .status-tag.completed {
            background-color: #2ecc71;
        }

        .status-tag.cancelled {
            background-color: #e74c3c;
        }

        @media (max-width: 768px) {
            .form-row {
                grid-template-columns: 1fr;
                gap: 0;
            }

            .search-bar {
                flex-direction: column;
                align-items: stretch;
            }
        }
    </style>
</body>

</html>