<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取出库记录ID
$log_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
$shipment_id = isset($_GET['shipment_id']) ? (int)$_GET['shipment_id'] : 0;

if ($log_id <= 0 && $shipment_id <= 0) {
    header("Location: finished_goods_inventory.php");
    exit;
}

$error_message = '';
$outbound_info = null;
$shipment_info = null;
$product_info = null;

try {
    // 如果有活动日志ID，优先查询活动日志
    if ($log_id > 0) {
        $stmt = $pdo->prepare("
            SELECT 
                al.*,
                u.full_name,
                p.name AS product_name,
                p.specification,
                p.type,
                p.unit
            FROM 
                activity_log al
            LEFT JOIN 
                users u ON al.user_id = u.id
            LEFT JOIN 
                products p ON al.target_type = 'product' AND al.target_id = p.id
            WHERE 
                al.id = ?
                AND al.action LIKE '%出库%'
        ");
        $stmt->execute([$log_id]);
        $outbound_info = $stmt->fetch();

        if (!$outbound_info) {
            throw new Exception("未找到相关出库记录");
        }

        // 解析出库数量和单位
        if (preg_match('/出库数量: ([\d\.]+) (\w+)/', $outbound_info['details'], $matches)) {
            $outbound_info['quantity'] = $matches[1];
            $outbound_info['unit'] = $matches[2];
        }

        // 获取产品详细信息
        $stmt = $pdo->prepare("
            SELECT 
                p.*,
                i.quantity_on_hand,
                sl.name AS location_name
            FROM 
                products p
            LEFT JOIN 
                inventory i ON p.id = i.product_id
            LEFT JOIN 
                storage_locations sl ON i.storage_location_id = sl.id
            WHERE 
                p.id = ?
        ");
        $stmt->execute([$outbound_info['target_id']]);
        $product_info = $stmt->fetch();
    }

    // 如果有发货ID，查询发货记录
    if ($shipment_id > 0) {
        $stmt = $pdo->prepare("
            SELECT 
                sh.*,
                so.order_number,
                so.customer_id,
                c.name AS customer_name,
                c.contact_person,
                c.phone,
                c.address,
                ca.name AS carrier_name,
                ca.service_type
            FROM 
                shipments sh
            LEFT JOIN 
                sales_orders so ON sh.sales_order_id = so.id
            LEFT JOIN 
                customers c ON so.customer_id = c.id
            LEFT JOIN 
                carriers ca ON sh.carrier_id = ca.id
            WHERE 
                sh.id = ?
        ");
        $stmt->execute([$shipment_id]);
        $shipment_info = $stmt->fetch();

        if (!$shipment_info) {
            throw new Exception("未找到相关发货记录");
        }

        // 获取订单项目
        $stmt = $pdo->prepare("
            SELECT 
                soi.*,
                p.name AS product_name,
                p.specification,
                p.unit
            FROM 
                sales_order_items soi
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                soi.sales_order_id = ?
        ");
        $stmt->execute([$shipment_info['sales_order_id']]);
        $shipment_info['items'] = $stmt->fetchAll();

        // 获取关联的活动日志
        $stmt = $pdo->prepare("
            SELECT 
                al.*,
                u.full_name
            FROM 
                activity_log al
            LEFT JOIN 
                users u ON al.user_id = u.id
            WHERE 
                al.target_type = 'shipment'
                AND al.target_id = ?
            ORDER BY 
                al.timestamp DESC
        ");
        $stmt->execute([$shipment_id]);
        $shipment_info['logs'] = $stmt->fetchAll();
    }
} catch (Exception $e) {
    $error_message = $e->getMessage();
}

// 发货状态映射
$shipmentStatusDisplay = [
    'pending' => ['text' => '待处理', 'class' => '待处理'],
    'ready_to_ship' => ['text' => '待发货', 'class' => '待处理'],
    'shipped' => ['text' => '已发货', 'class' => '进行中'],
    'in_transit' => ['text' => '运输中', 'class' => '进行中'],
    'delivered' => ['text' => '已送达', 'class' => '已完成'],
    'failed' => ['text' => '失败', 'class' => '待处理'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>出库详情</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .container {
            max-width: 800px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .section {
            margin-bottom: 20px;
            padding: 15px;
            border: 1px solid #e9ecef;
            border-radius: 8px;
            background-color: #f8f9fa;
        }

        .section-title {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 15px;
            color: #495057;
            border-bottom: 1px solid #dee2e6;
            padding-bottom: 8px;
        }

        .info-grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 10px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
            margin-right: 5px;
        }

        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
        }

        .待处理 {
            background: #f39c12;
            color: white;
        }

        .进行中 {
            background: #3498db;
            color: white;
        }

        .已完成 {
            background: #2ecc71;
            color: white;
        }

        .btn-container {
            display: flex;
            justify-content: space-between;
            margin-top: 20px;
        }

        .btn {
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            text-decoration: none;
            display: inline-block;
            text-align: center;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
        }

        .btn-secondary {
            background-color: #6c757d;
            color: white;
        }

        .btn-primary:hover {
            background-color: #2980b9;
        }

        .btn-secondary:hover {
            background-color: #5a6268;
        }

        .alert {
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        .log-item {
            padding: 10px;
            border-bottom: 1px solid #eee;
            font-size: 0.9em;
        }

        .log-item:last-child {
            border-bottom: none;
        }

        .log-time {
            color: #6c757d;
            font-size: 0.85em;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 15px;
        }

        table th,
        table td {
            padding: 8px;
            border: 1px solid #ddd;
            text-align: left;
        }

        table th {
            background-color: #f5f5f5;
        }

        table tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        .detail-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .detail-title {
            font-size: 24px;
            color: #343a40;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="detail-header">
            <h2 class="detail-title">出库详情</h2>
            <?php if ($shipment_info): ?>
                <?php $shipmentStatus = $shipmentStatusDisplay[$shipment_info['status']] ?? ['text' => $shipment_info['status'], 'class' => '']; ?>
                <div class="status-tag <?= $shipmentStatus['class'] ?>"><?= $shipmentStatus['text'] ?></div>
            <?php endif; ?>
        </div>

        <?php if ($error_message): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <?php if ($outbound_info): ?>
            <!-- 一般出库记录详情 -->
            <div class="section">
                <div class="section-title">出库信息</div>
                <div class="info-grid">
                    <div class="info-item">
                        <span class="info-label">出库类型:</span>
                        <?= $outbound_info['action'] ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">出库时间:</span>
                        <?= date('Y-m-d H:i:s', strtotime($outbound_info['timestamp'])) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">操作人员:</span>
                        <?= htmlspecialchars($outbound_info['full_name'] ?: $outbound_info['username']) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">出库数量:</span>
                        <?= isset($outbound_info['quantity']) ? number_format($outbound_info['quantity'], 2) . ' ' . $outbound_info['unit'] : '未知' ?>
                    </div>
                </div>
                <div class="info-item">
                    <span class="info-label">备注详情:</span>
                    <div><?= nl2br(htmlspecialchars($outbound_info['details'])) ?></div>
                </div>
            </div>

            <?php if ($product_info): ?>
                <div class="section">
                    <div class="section-title">产品信息</div>
                    <div class="info-grid">
                        <div class="info-item">
                            <span class="info-label">产品名称:</span>
                            <?= htmlspecialchars($product_info['name']) ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">产品规格:</span>
                            <?= htmlspecialchars($product_info['specification'] ?: '无') ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">产品类型:</span>
                            <?php
                            $typeMap = [
                                'raw' => '原料',
                                'semi-finished' => '半成品',
                                'finished' => '成品'
                            ];
                            echo $typeMap[$product_info['type']] ?? $product_info['type'];
                            ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">计量单位:</span>
                            <?= htmlspecialchars($product_info['unit']) ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">当前库存:</span>
                            <?= number_format($product_info['quantity_on_hand'], 2) . ' ' . $product_info['unit'] ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">存放位置:</span>
                            <?= htmlspecialchars($product_info['location_name'] ?: '未知') ?>
                        </div>
                    </div>
                    <?php if ($product_info['description']): ?>
                        <div class="info-item">
                            <span class="info-label">产品描述:</span>
                            <div><?= nl2br(htmlspecialchars($product_info['description'])) ?></div>
                        </div>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        <?php endif; ?>

        <?php if ($shipment_info): ?>
            <!-- 发货记录详情 -->
            <div class="section">
                <div class="section-title">发货信息</div>
                <div class="info-grid">
                    <div class="info-item">
                        <span class="info-label">发货单号:</span>
                        <?= htmlspecialchars($shipment_info['shipment_number']) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">订单编号:</span>
                        <?= htmlspecialchars($shipment_info['order_number']) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">发货日期:</span>
                        <?= date('Y-m-d H:i:s', strtotime($shipment_info['shipment_date'])) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">客户名称:</span>
                        <?= htmlspecialchars($shipment_info['customer_name']) ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">联系人:</span>
                        <?= htmlspecialchars($shipment_info['contact_person'] ?: '无') ?>
                    </div>
                    <div class="info-item">
                        <span class="info-label">联系电话:</span>
                        <?= htmlspecialchars($shipment_info['phone'] ?: '无') ?>
                    </div>
                </div>
                <div class="info-item">
                    <span class="info-label">收货地址:</span>
                    <div><?= htmlspecialchars($shipment_info['address'] ?: '无') ?></div>
                </div>
                <?php if ($shipment_info['notes']): ?>
                    <div class="info-item">
                        <span class="info-label">备注说明:</span>
                        <div><?= nl2br(htmlspecialchars($shipment_info['notes'])) ?></div>
                    </div>
                <?php endif; ?>
            </div>

            <?php if (!empty($shipment_info['carrier_name'])): ?>
                <div class="section">
                    <div class="section-title">物流信息</div>
                    <div class="info-grid">
                        <div class="info-item">
                            <span class="info-label">物流公司:</span>
                            <?= htmlspecialchars($shipment_info['carrier_name']) ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">服务类型:</span>
                            <?= htmlspecialchars($shipment_info['service_type'] ?: '普通') ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">物流单号:</span>
                            <?= htmlspecialchars($shipment_info['tracking_number'] ?: '暂无') ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">预计送达日期:</span>
                            <?= $shipment_info['estimated_delivery_date'] ? date('Y-m-d', strtotime($shipment_info['estimated_delivery_date'])) : '暂无' ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">实际送达日期:</span>
                            <?= $shipment_info['actual_delivery_date'] ? date('Y-m-d H:i:s', strtotime($shipment_info['actual_delivery_date'])) : '暂无' ?>
                        </div>
                        <div class="info-item">
                            <span class="info-label">物流费用:</span>
                            <?= $shipment_info['shipping_cost'] ? number_format($shipment_info['shipping_cost'], 2) . ' 元' : '未记录' ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <?php if (!empty($shipment_info['items'])): ?>
                <div class="section">
                    <div class="section-title">发货商品</div>
                    <table>
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>规格</th>
                                <th>单位</th>
                                <th>订单数量</th>
                                <th>发货数量</th>
                                <th>单价</th>
                                <th>金额</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($shipment_info['items'] as $item): ?>
                                <?php
                                $amount = $item['quantity'] * $item['unit_price'] * (1 - $item['discount_rate']);
                                ?>
                                <tr>
                                    <td><?= htmlspecialchars($item['product_name']) ?></td>
                                    <td><?= htmlspecialchars($item['specification'] ?: '-') ?></td>
                                    <td><?= htmlspecialchars($item['unit']) ?></td>
                                    <td><?= number_format($item['quantity'], 2) ?></td>
                                    <td><?= number_format($item['shipped_quantity'], 2) ?></td>
                                    <td><?= number_format($item['unit_price'], 2) ?> 元</td>
                                    <td><?= number_format($amount, 2) ?> 元</td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>

            <?php if (!empty($shipment_info['logs'])): ?>
                <div class="section">
                    <div class="section-title">操作日志</div>
                    <div class="log-list">
                        <?php foreach ($shipment_info['logs'] as $log): ?>
                            <div class="log-item">
                                <div><?= htmlspecialchars($log['action']) ?> - <?= htmlspecialchars($log['full_name'] ?: $log['username']) ?></div>
                                <?php if ($log['details']): ?>
                                    <div><?= htmlspecialchars($log['details']) ?></div>
                                <?php endif; ?>
                                <div class="log-time"><?= date('Y-m-d H:i:s', strtotime($log['timestamp'])) ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            <?php endif; ?>
        <?php endif; ?>

        <div class="btn-container">
            <a href="finished_goods_inventory.php" class="btn btn-secondary">返回库存列表</a>
            <?php if ($shipment_info && $shipment_info['status'] == 'ready_to_ship'): ?>
                <a href="update_shipment.php?id=<?= $shipment_id ?>" class="btn btn-primary">更新发货信息</a>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>