<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查必要的表是否存在，不存在则创建
try {
    // 检查warehouse_environment_records表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'warehouse_environment_records'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建仓库环境记录表
            CREATE TABLE IF NOT EXISTS `warehouse_environment_records` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '记录ID',
              `storage_location_id` INT UNSIGNED NOT NULL COMMENT '仓库位置ID',
              `record_time` DATETIME NOT NULL COMMENT '记录时间',
              `temperature` DECIMAL(5, 2) NOT NULL COMMENT '温度(°C)',
              `humidity` DECIMAL(5, 2) DEFAULT NULL COMMENT '湿度(%)',
              `is_normal` BOOLEAN NOT NULL DEFAULT TRUE COMMENT '是否正常',
              `notes` TEXT DEFAULT NULL COMMENT '备注',
              `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '记录人员ID',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              PRIMARY KEY (`id`),
              KEY `idx_environment_location` (`storage_location_id`),
              KEY `idx_environment_time` (`record_time`),
              KEY `idx_environment_user` (`created_by_user_id`),
              KEY `idx_environment_status` (`is_normal`),
              CONSTRAINT `fk_environment_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT,
              CONSTRAINT `fk_environment_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='仓库环境记录表'
        ");
    }

    // 检查warehouse_environment_settings表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'warehouse_environment_settings'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建仓库环境设置表
            CREATE TABLE IF NOT EXISTS `warehouse_environment_settings` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '设置ID',
              `storage_location_id` INT UNSIGNED NOT NULL COMMENT '仓库位置ID',
              `min_temperature` DECIMAL(5, 2) NOT NULL COMMENT '最低温度(°C)',
              `max_temperature` DECIMAL(5, 2) NOT NULL COMMENT '最高温度(°C)',
              `min_humidity` DECIMAL(5, 2) DEFAULT NULL COMMENT '最低湿度(%)',
              `max_humidity` DECIMAL(5, 2) DEFAULT NULL COMMENT '最高湿度(%)',
              `check_interval_hours` INT UNSIGNED NOT NULL DEFAULT 4 COMMENT '检查间隔(小时)',
              `alarm_enabled` BOOLEAN NOT NULL DEFAULT TRUE COMMENT '报警是否启用',
              `updated_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '更新人员ID',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              UNIQUE KEY `uk_environment_location` (`storage_location_id`),
              CONSTRAINT `fk_environment_settings_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE CASCADE,
              CONSTRAINT `fk_environment_settings_user` FOREIGN KEY (`updated_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='仓库环境设置表'
        ");
    }

    // 检查warehouse_environment_alarms表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'warehouse_environment_alarms'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建仓库环境报警表
            CREATE TABLE IF NOT EXISTS `warehouse_environment_alarms` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '报警ID',
              `record_id` INT UNSIGNED NOT NULL COMMENT '关联记录ID',
              `storage_location_id` INT UNSIGNED NOT NULL COMMENT '仓库位置ID',
              `alarm_time` DATETIME NOT NULL COMMENT '报警时间',
              `alarm_type` ENUM('temperature_high', 'temperature_low', 'humidity_high', 'humidity_low') NOT NULL COMMENT '报警类型',
              `alarm_value` DECIMAL(5, 2) NOT NULL COMMENT '报警值',
              `threshold_value` DECIMAL(5, 2) NOT NULL COMMENT '阈值',
              `is_handled` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否已处理',
              `handled_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '处理人员ID',
              `handled_time` DATETIME DEFAULT NULL COMMENT '处理时间',
              `handling_notes` TEXT DEFAULT NULL COMMENT '处理备注',
              PRIMARY KEY (`id`),
              KEY `idx_alarm_record` (`record_id`),
              KEY `idx_alarm_location` (`storage_location_id`),
              KEY `idx_alarm_time` (`alarm_time`),
              KEY `idx_alarm_handled` (`is_handled`),
              CONSTRAINT `fk_alarm_record` FOREIGN KEY (`record_id`) REFERENCES `warehouse_environment_records` (`id`) ON DELETE CASCADE,
              CONSTRAINT `fk_alarm_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='仓库环境报警表'
        ");
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败：" . $e->getMessage();
}

// 初始化变量
$error = '';
$success = '';
$active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'record';
$location_id = isset($_GET['location_id']) ? (int)$_GET['location_id'] : 0;
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-7 day'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$show_alarms_only = isset($_GET['show_alarms_only']) ? (bool)$_GET['show_alarms_only'] : false;

// 获取仓库位置
try {
    $stmt = $pdo->query("
        SELECT 
            id, 
            name, 
            type, 
            temperature_controlled, 
            humidity_controlled
        FROM 
            storage_locations
        ORDER BY 
            name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 筛选出温控和湿控仓库
$environment_controlled_locations = array_filter($locations, function ($location) {
    return $location['temperature_controlled'] || $location['humidity_controlled'];
});

// 如果没有选择仓库且有温控仓库，默认选择第一个
if ($location_id == 0 && !empty($environment_controlled_locations)) {
    $location_id = reset($environment_controlled_locations)['id'];
}

// 获取选中仓库的详细信息
$selected_location = null;
if ($location_id > 0) {
    foreach ($locations as $loc) {
        if ($loc['id'] == $location_id) {
            $selected_location = $loc;
            break;
        }
    }
}

// 处理表单提交 - 添加环境记录
if (isset($_POST['add_record'])) {
    try {
        if (!$selected_location) {
            throw new Exception("请先选择仓库位置！");
        }

        $record_time = isset($_POST['record_time']) ? $_POST['record_time'] : date('Y-m-d H:i:s');
        $temperature = isset($_POST['temperature']) ? (float)$_POST['temperature'] : 0;
        $humidity = isset($_POST['humidity']) ? (float)$_POST['humidity'] : null;
        $notes = isset($_POST['notes']) ? $_POST['notes'] : '';

        // 验证数据
        if (!$temperature && $temperature !== 0) {
            throw new Exception("请输入有效的温度值！");
        }

        if ($selected_location['humidity_controlled'] && $humidity === null) {
            throw new Exception("湿度控制仓库必须输入湿度值！");
        }

        // 检查是否有设置环境参数
        $stmt = $pdo->prepare("
            SELECT * FROM warehouse_environment_settings 
            WHERE storage_location_id = ?
        ");
        $stmt->execute([$location_id]);
        $settings = $stmt->fetch();

        // 判断是否异常
        $is_normal = true;
        $alarm_type = null;
        $threshold_value = null;
        $alarm_value = null;

        if ($settings) {
            // 温度异常检查
            if ($temperature < $settings['min_temperature']) {
                $is_normal = false;
                $alarm_type = 'temperature_low';
                $threshold_value = $settings['min_temperature'];
                $alarm_value = $temperature;
            } elseif ($temperature > $settings['max_temperature']) {
                $is_normal = false;
                $alarm_type = 'temperature_high';
                $threshold_value = $settings['max_temperature'];
                $alarm_value = $temperature;
            }

            // 湿度异常检查（如果有湿度值）
            if ($humidity !== null && $settings['min_humidity'] !== null && $settings['max_humidity'] !== null) {
                if ($humidity < $settings['min_humidity']) {
                    $is_normal = false;
                    if ($alarm_type === null) { // 温度正常但湿度异常
                        $alarm_type = 'humidity_low';
                        $threshold_value = $settings['min_humidity'];
                        $alarm_value = $humidity;
                    }
                } elseif ($humidity > $settings['max_humidity']) {
                    $is_normal = false;
                    if ($alarm_type === null) { // 温度正常但湿度异常
                        $alarm_type = 'humidity_high';
                        $threshold_value = $settings['max_humidity'];
                        $alarm_value = $humidity;
                    }
                }
            }
        }

        // 开始事务
        $pdo->beginTransaction();

        // 插入环境记录
        $stmt = $pdo->prepare("
            INSERT INTO warehouse_environment_records (
                storage_location_id, 
                record_time, 
                temperature, 
                humidity, 
                is_normal, 
                notes, 
                created_by_user_id
            ) VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $location_id,
            $record_time,
            $temperature,
            $humidity,
            $is_normal,
            $notes,
            $_SESSION['user_id']
        ]);

        $record_id = $pdo->lastInsertId();

        // 如果异常且启用了报警，则添加报警记录
        if (!$is_normal && $alarm_type && $settings && $settings['alarm_enabled']) {
            $stmt = $pdo->prepare("
                INSERT INTO warehouse_environment_alarms (
                    record_id,
                    storage_location_id,
                    alarm_time,
                    alarm_type,
                    alarm_value,
                    threshold_value
                ) VALUES (?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $record_id,
                $location_id,
                $record_time,
                $alarm_type,
                $alarm_value,
                $threshold_value
            ]);
        }

        // 提交事务
        $pdo->commit();
        $success = "环境记录添加成功！" . (!$is_normal ? "已记录异常情况。" : "");
    } catch (Exception $e) {
        // 回滚事务
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $error = "添加环境记录失败：" . $e->getMessage();
    }
}

// 处理表单提交 - 更新环境设置
if (isset($_POST['update_settings'])) {
    try {
        if (!$selected_location) {
            throw new Exception("请先选择仓库位置！");
        }

        $min_temperature = isset($_POST['min_temperature']) ? (float)$_POST['min_temperature'] : 0;
        $max_temperature = isset($_POST['max_temperature']) ? (float)$_POST['max_temperature'] : 0;
        $min_humidity = isset($_POST['min_humidity']) ? (float)$_POST['min_humidity'] : null;
        $max_humidity = isset($_POST['max_humidity']) ? (float)$_POST['max_humidity'] : null;
        $check_interval_hours = isset($_POST['check_interval_hours']) ? (int)$_POST['check_interval_hours'] : 4;
        $alarm_enabled = isset($_POST['alarm_enabled']) ? 1 : 0;

        // 验证数据
        if ($min_temperature >= $max_temperature) {
            throw new Exception("最低温度必须小于最高温度！");
        }

        if ($selected_location['humidity_controlled'] && ($min_humidity === null || $max_humidity === null)) {
            throw new Exception("湿度控制仓库必须设置湿度范围！");
        }

        if ($selected_location['humidity_controlled'] && $min_humidity >= $max_humidity) {
            throw new Exception("最低湿度必须小于最高湿度！");
        }

        if ($check_interval_hours <= 0) {
            throw new Exception("检查间隔必须大于0！");
        }

        // 检查是否已有设置
        $stmt = $pdo->prepare("
            SELECT id FROM warehouse_environment_settings 
            WHERE storage_location_id = ?
        ");
        $stmt->execute([$location_id]);
        $existing_settings = $stmt->fetch();

        if ($existing_settings) {
            // 更新现有设置
            $stmt = $pdo->prepare("
                UPDATE warehouse_environment_settings 
                SET 
                    min_temperature = ?,
                    max_temperature = ?,
                    min_humidity = ?,
                    max_humidity = ?,
                    check_interval_hours = ?,
                    alarm_enabled = ?,
                    updated_by_user_id = ?
                WHERE id = ?
            ");
            $stmt->execute([
                $min_temperature,
                $max_temperature,
                $min_humidity,
                $max_humidity,
                $check_interval_hours,
                $alarm_enabled,
                $_SESSION['user_id'],
                $existing_settings['id']
            ]);
        } else {
            // 新增设置
            $stmt = $pdo->prepare("
                INSERT INTO warehouse_environment_settings (
                    storage_location_id,
                    min_temperature,
                    max_temperature,
                    min_humidity,
                    max_humidity,
                    check_interval_hours,
                    alarm_enabled,
                    updated_by_user_id
                ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $location_id,
                $min_temperature,
                $max_temperature,
                $min_humidity,
                $max_humidity,
                $check_interval_hours,
                $alarm_enabled,
                $_SESSION['user_id']
            ]);
        }

        $success = "环境设置更新成功！";
    } catch (Exception $e) {
        $error = "更新环境设置失败：" . $e->getMessage();
    }
}

// 处理报警处理
if (isset($_POST['handle_alarm'])) {
    try {
        $alarm_id = isset($_POST['alarm_id']) ? (int)$_POST['alarm_id'] : 0;
        $handling_notes = isset($_POST['handling_notes']) ? $_POST['handling_notes'] : '';

        if ($alarm_id <= 0) {
            throw new Exception("无效的报警ID！");
        }

        if (empty($handling_notes)) {
            throw new Exception("请输入处理备注！");
        }

        // 更新报警状态
        $stmt = $pdo->prepare("
            UPDATE warehouse_environment_alarms
            SET
                is_handled = 1,
                handled_by_user_id = ?,
                handled_time = NOW(),
                handling_notes = ?
            WHERE id = ?
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $handling_notes,
            $alarm_id
        ]);

        if ($stmt->rowCount() == 0) {
            throw new Exception("报警记录不存在或已处理！");
        }

        $success = "报警已成功标记为已处理！";
    } catch (Exception $e) {
        $error = "处理报警失败：" . $e->getMessage();
    }
}

// 获取当前仓库的环境设置
$current_settings = null;
if ($location_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT * FROM warehouse_environment_settings
            WHERE storage_location_id = ?
        ");
        $stmt->execute([$location_id]);
        $current_settings = $stmt->fetch();
    } catch (PDOException $e) {
        $error = "获取环境设置失败：" . $e->getMessage();
    }
}

// 获取环境记录
$environment_records = [];
if ($location_id > 0) {
    try {
        $query = "
            SELECT 
                wer.*,
                CASE 
                    WHEN wer.is_normal = 0 THEN 1
                    ELSE 0
                END AS has_alarm,
                u.username AS created_by
            FROM 
                warehouse_environment_records wer
            LEFT JOIN 
                users u ON wer.created_by_user_id = u.id
            WHERE 
                wer.storage_location_id = ?
                AND DATE(wer.record_time) BETWEEN ? AND ?
        ";

        $params = [$location_id, $start_date, $end_date];

        if ($show_alarms_only) {
            $query .= " AND wer.is_normal = 0";
        }

        $query .= " ORDER BY wer.record_time DESC";

        $stmt = $pdo->prepare($query);
        $stmt->execute($params);
        $environment_records = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = "获取环境记录失败：" . $e->getMessage();
    }
}

// 获取未处理的报警记录
$pending_alarms = [];
try {
    $stmt = $pdo->prepare("
        SELECT 
            wea.*,
            wer.record_time,
            wer.temperature,
            wer.humidity,
            sl.name AS location_name
        FROM 
            warehouse_environment_alarms wea
        JOIN 
            warehouse_environment_records wer ON wea.record_id = wer.id
        JOIN 
            storage_locations sl ON wea.storage_location_id = sl.id
        WHERE 
            wea.is_handled = 0
        ORDER BY 
            wea.alarm_time DESC
    ");
    $stmt->execute();
    $pending_alarms = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取报警记录失败：" . $e->getMessage();
}

// 获取报警历史记录
$alarm_history = [];
if ($location_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT 
                wea.*,
                wer.record_time,
                wer.temperature,
                wer.humidity,
                sl.name AS location_name,
                u.username AS handled_by
            FROM 
                warehouse_environment_alarms wea
            JOIN 
                warehouse_environment_records wer ON wea.record_id = wer.id
            JOIN 
                storage_locations sl ON wea.storage_location_id = sl.id
            LEFT JOIN 
                users u ON wea.handled_by_user_id = u.id
            WHERE 
                wea.storage_location_id = ?
                AND DATE(wea.alarm_time) BETWEEN ? AND ?
            ORDER BY 
                wea.alarm_time DESC
        ");
        $stmt->execute([$location_id, $start_date, $end_date]);
        $alarm_history = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = "获取报警历史记录失败：" . $e->getMessage();
    }
}

// 获取统计数据
$stats = [];
if ($location_id > 0) {
    try {
        // 获取温度统计
        $stmt = $pdo->prepare("
            SELECT 
                MIN(temperature) AS min_temp,
                MAX(temperature) AS max_temp,
                AVG(temperature) AS avg_temp,
                MIN(humidity) AS min_humidity,
                MAX(humidity) AS max_humidity,
                AVG(humidity) AS avg_humidity,
                COUNT(*) AS record_count,
                SUM(CASE WHEN is_normal = 0 THEN 1 ELSE 0 END) AS abnormal_count
            FROM 
                warehouse_environment_records
            WHERE 
                storage_location_id = ?
                AND DATE(record_time) BETWEEN ? AND ?
        ");
        $stmt->execute([$location_id, $start_date, $end_date]);
        $stats = $stmt->fetch();

        // 获取每日温度数据用于图表
        $stmt = $pdo->prepare("
            SELECT 
                DATE(record_time) AS record_date,
                AVG(temperature) AS avg_temp,
                MIN(temperature) AS min_temp,
                MAX(temperature) AS max_temp,
                AVG(humidity) AS avg_humidity,
                MIN(humidity) AS min_humidity,
                MAX(humidity) AS max_humidity,
                COUNT(*) AS record_count,
                SUM(CASE WHEN is_normal = 0 THEN 1 ELSE 0 END) AS abnormal_count
            FROM 
                warehouse_environment_records
            WHERE 
                storage_location_id = ?
                AND DATE(record_time) BETWEEN ? AND ?
            GROUP BY 
                DATE(record_time)
            ORDER BY 
                record_date
        ");
        $stmt->execute([$location_id, $start_date, $end_date]);
        $daily_stats = $stmt->fetchAll();

        // 转换为图表格式
        $chart_dates = [];
        $chart_temp_data = [];
        $chart_humidity_data = [];
        $chart_abnormal_counts = [];

        foreach ($daily_stats as $day) {
            $chart_dates[] = $day['record_date'];
            $chart_temp_data[] = [
                'avg' => round($day['avg_temp'], 1),
                'min' => round($day['min_temp'], 1),
                'max' => round($day['max_temp'], 1)
            ];

            if ($selected_location['humidity_controlled']) {
                $chart_humidity_data[] = [
                    'avg' => $day['avg_humidity'] ? round($day['avg_humidity'], 1) : null,
                    'min' => $day['min_humidity'] ? round($day['min_humidity'], 1) : null,
                    'max' => $day['max_humidity'] ? round($day['max_humidity'], 1) : null
                ];
            }

            $chart_abnormal_counts[] = (int)$day['abnormal_count'];
        }
    } catch (PDOException $e) {
        $error = "获取统计数据失败：" . $e->getMessage();
    }
}

// 报警类型映射
$alarm_type_map = [
    'temperature_high' => '温度过高',
    'temperature_low' => '温度过低',
    'humidity_high' => '湿度过高',
    'humidity_low' => '湿度过低'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>仓库环境管理 - <?= title ?></title>
    <link rel="stylesheet" href="style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="date"],
        .form-group input[type="text"],
        .form-group input[type="number"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        /* 标签页样式 */
        .tabs {
            display: flex;
            margin-bottom: 25px;
            border-bottom: 1px solid #ddd;
            background: white;
            border-radius: 8px 8px 0 0;
            overflow: hidden;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .tab {
            padding: 12px 20px;
            cursor: pointer;
            font-weight: bold;
            transition: all 0.3s;
            text-align: center;
            flex: 1;
            border-bottom: 3px solid transparent;
        }

        .tab:hover {
            background-color: #f8f9fa;
        }

        .tab.active {
            background: #3498db;
            color: white;
            border-bottom: 3px solid #2980b9;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
            animation: fadeIn 0.5s;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }

        /* 表格样式 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
            background: white;
            border-radius: 6px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        /* 按钮样式 */
        button,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            transition: background 0.3s;
        }

        button:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        /* 图表和卡片样式 */
        .card {
            margin-bottom: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
            overflow: hidden;
        }

        .card-header {
            background-color: #f8f9fa;
            padding: 15px 20px;
            border-bottom: 1px solid #eaeaea;
        }

        .card-body {
            padding: 20px;
        }

        /* 报警状态样式 */
        .badge {
            padding: 5px 10px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
        }

        .bg-success {
            background-color: #28a745 !important;
            color: white;
        }

        .bg-danger {
            background-color: #dc3545 !important;
            color: white;
        }

        /* 消息样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        .alert-info {
            background-color: #d1ecf1;
            color: #0c5460;
            border: 1px solid #bee5eb;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>仓库环境管理</h1>

        <?php if ($error): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <?php if ($success): ?>
            <div class="alert alert-success"><?= $success ?></div>
        <?php endif; ?>

        <!-- 仓库位置选择和日期范围 -->
        <div class="section">
            <form method="get" class="check-form">
                <div class="form-group">
                    <label for="location_id">仓库位置:</label>
                    <select id="location_id" name="location_id" onchange="this.form.submit()">
                        <option value="">-- 选择仓库 --</option>
                        <?php foreach ($locations as $loc): ?>
                            <option value="<?= $loc['id'] ?>" <?= $location_id == $loc['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($loc['name']) ?>
                                <?= $loc['temperature_controlled'] ? ' (温控)' : '' ?>
                                <?= $loc['humidity_controlled'] ? ' (湿控)' : '' ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <?php if ($location_id): ?>
                    <input type="hidden" name="location_id" value="<?= $location_id ?>">
                    <div class="form-group">
                        <label for="start_date">开始日期:</label>
                        <input type="date" id="start_date" name="start_date" value="<?= $start_date ?>">
                    </div>
                    <div class="form-group">
                        <label for="end_date">结束日期:</label>
                        <input type="date" id="end_date" name="end_date" value="<?= $end_date ?>">
                    </div>
                    <div class="form-group">
                        <button type="submit">查询</button>
                    </div>
                <?php endif; ?>
            </form>
        </div>

        <?php if ($selected_location): ?>
            <!-- 标签页导航 -->
            <div class="tabs">
                <div class="tab active" onclick="switchTab('records-tab')">环境记录</div>
                <div class="tab" onclick="switchTab('settings-tab')">环境设置</div>
                <div class="tab" onclick="switchTab('alarms-tab')">报警记录</div>
                <div class="tab" onclick="switchTab('stats-tab')">统计分析</div>
            </div>

            <!-- 环境记录标签页 -->
            <div id="records-tab" class="tab-content active">
                <div class="section">
                    <h2>环境记录
                        <button type="button" class="btn-primary" style="float:right" onclick="showModal('addRecordModal')">
                            添加记录
                        </button>
                    </h2>
                    <div class="table-container">
                        <table>
                            <thead>
                                <tr>
                                    <th>记录时间</th>
                                    <th>温度(℃)</th>
                                    <th>湿度(%)</th>
                                    <th>状态</th>
                                    <th>记录人</th>
                                    <th>备注</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($environment_records as $record): ?>
                                    <tr>
                                        <td><?= date('Y-m-d H:i:s', strtotime($record['record_time'])) ?></td>
                                        <td><?= $record['temperature'] ?></td>
                                        <td><?= $record['humidity'] ?></td>
                                        <td>
                                            <?php if ($record['is_normal']): ?>
                                                <span class="status-tag 已完成">正常</span>
                                            <?php else: ?>
                                                <span class="status-tag 待处理">异常</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?= htmlspecialchars($record['created_by']) ?></td>
                                        <td><?= htmlspecialchars($record['notes']) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 环境设置标签页 -->
            <div id="settings-tab" class="tab-content">
                <div class="section">
                    <h2>环境设置</h2>
                    <form method="post" class="form-container">
                        <input type="hidden" name="update_settings" value="1">
                        <div class="form-group">
                            <label>温度范围(℃)</label>
                            <div style="display: flex; gap: 10px;">
                                <input type="number" step="0.1" name="min_temperature" placeholder="最低温度"
                                    value="<?= $current_settings ? $current_settings['min_temperature'] : '' ?>" required>
                                <span style="align-self: center;">至</span>
                                <input type="number" step="0.1" name="max_temperature" placeholder="最高温度"
                                    value="<?= $current_settings ? $current_settings['max_temperature'] : '' ?>" required>
                            </div>
                        </div>
                        <?php if ($selected_location['humidity_controlled']): ?>
                            <div class="form-group">
                                <label>湿度范围(%)</label>
                                <div style="display: flex; gap: 10px;">
                                    <input type="number" step="0.1" name="min_humidity" placeholder="最低湿度"
                                        value="<?= $current_settings ? $current_settings['min_humidity'] : '' ?>" required>
                                    <span style="align-self: center;">至</span>
                                    <input type="number" step="0.1" name="max_humidity" placeholder="最高湿度"
                                        value="<?= $current_settings ? $current_settings['max_humidity'] : '' ?>" required>
                                </div>
                            </div>
                        <?php endif; ?>
                        <div class="form-group">
                            <label>检查间隔(小时)</label>
                            <input type="number" name="check_interval_hours"
                                value="<?= $current_settings ? $current_settings['check_interval_hours'] : 4 ?>" required>
                        </div>
                        <div class="form-group">
                            <label>
                                <input type="checkbox" name="alarm_enabled"
                                    <?= $current_settings && $current_settings['alarm_enabled'] ? 'checked' : '' ?>>
                                启用报警
                            </label>
                        </div>
                        <div class="form-group">
                            <button type="submit">保存设置</button>
                        </div>
                    </form>
                </div>
            </div>

            <!-- 报警记录标签页 -->
            <div id="alarms-tab" class="tab-content">
                <div class="section">
                    <h2>报警记录</h2>
                    <div class="table-container">
                        <table>
                            <thead>
                                <tr>
                                    <th>报警时间</th>
                                    <th>报警类型</th>
                                    <th>报警值</th>
                                    <th>阈值</th>
                                    <th>状态</th>
                                    <th>处理人</th>
                                    <th>处理时间</th>
                                    <th>处理备注</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($alarm_history as $alarm): ?>
                                    <tr>
                                        <td><?= date('Y-m-d H:i:s', strtotime($alarm['alarm_time'])) ?></td>
                                        <td><?= $alarm_type_map[$alarm['alarm_type']] ?></td>
                                        <td><?= $alarm['alarm_value'] ?></td>
                                        <td><?= $alarm['threshold_value'] ?></td>
                                        <td>
                                            <?php if ($alarm['is_handled']): ?>
                                                <span class="status-tag 已完成">已处理</span>
                                            <?php else: ?>
                                                <span class="status-tag 待处理">未处理</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?= $alarm['handled_by'] ? htmlspecialchars($alarm['handled_by']) : '-' ?></td>
                                        <td><?= $alarm['handled_time'] ? date('Y-m-d H:i:s', strtotime($alarm['handled_time'])) : '-' ?></td>
                                        <td><?= $alarm['handling_notes'] ? htmlspecialchars($alarm['handling_notes']) : '-' ?></td>
                                        <td>
                                            <?php if (!$alarm['is_handled']): ?>
                                                <button type="button" class="btn-link"
                                                    onclick="handleAlarm(<?= $alarm['id'] ?>)">
                                                    处理
                                                </button>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 统计分析标签页 -->
            <div id="stats-tab" class="tab-content">
                <div class="section">
                    <h2>统计分析</h2>
                    <div class="analysis-container">
                        <div class="analysis-card">
                            <h3>温度统计</h3>
                            <ul>
                                <li>平均温度: <?= round($stats['avg_temp'], 1) ?>℃</li>
                                <li>温度范围: <?= round($stats['min_temp'], 1) ?>℃ ~ <?= round($stats['max_temp'], 1) ?>℃</li>
                                <li>标准差: <?= round($stats['std_temp'], 2) ?></li>
                            </ul>
                        </div>
                        <?php if ($selected_location['humidity_controlled']): ?>
                            <div class="analysis-card">
                                <h3>湿度统计</h3>
                                <ul>
                                    <li>平均湿度: <?= round($stats['avg_humidity'], 1) ?>%</li>
                                    <li>湿度范围: <?= round($stats['min_humidity'], 1) ?>% ~ <?= round($stats['max_humidity'], 1) ?>%</li>
                                    <li>标准差: <?= round($stats['std_humidity'], 2) ?></li>
                                </ul>
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="chart-container">
                        <canvas id="temperatureChart" height="200"></canvas>
                    </div>
                    <?php if ($selected_location['humidity_controlled']): ?>
                        <div class="chart-container">
                            <canvas id="humidityChart" height="200"></canvas>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <!-- 添加记录模态框 HTML -->
            <div id="addRecordModal" class="modal" style="display: none;">
                <div class="modal-content">
                    <span class="close" onclick="hideModal('addRecordModal')">&times;</span>
                    <h2>添加环境记录</h2>
                    <form method="post">
                        <div class="form-group">
                            <label>温度(℃)</label>
                            <input type="number" step="0.1" name="temperature" required>
                        </div>
                        <?php if ($selected_location['humidity_controlled']): ?>
                            <div class="form-group">
                                <label>湿度(%)</label>
                                <input type="number" step="0.1" name="humidity" required>
                            </div>
                        <?php endif; ?>
                        <div class="form-group">
                            <label>备注</label>
                            <textarea name="notes" rows="3"></textarea>
                        </div>
                        <div class="form-group">
                            <button type="submit" name="add_record">保存</button>
                            <button type="button" onclick="hideModal('addRecordModal')" style="background-color: #6c757d;">取消</button>
                        </div>
                    </form>
                </div>
            </div>

            <!-- 处理报警模态框 HTML -->
            <div id="handleAlarmModal" class="modal" style="display: none;">
                <div class="modal-content">
                    <span class="close" onclick="hideModal('handleAlarmModal')">&times;</span>
                    <h2>处理报警</h2>
                    <form method="post">
                        <input type="hidden" name="handle_alarm" value="1">
                        <input type="hidden" name="alarm_id" id="alarmId">
                        <div class="form-group">
                            <label>处理备注</label>
                            <textarea name="handling_notes" rows="3" required></textarea>
                        </div>
                        <div class="form-group">
                            <button type="submit">确认处理</button>
                            <button type="button" onclick="hideModal('handleAlarmModal')" style="background-color: #6c757d;">取消</button>
                        </div>
                    </form>
                </div>
            </div>

        <?php else: ?>
            <div class="alert alert-info">
                请先选择仓库位置以查看环境记录
            </div>
        <?php endif; ?>
    </div>

    <!-- 模态框样式 -->
    <style>
        .modal {
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
        }

        .modal-content {
            background-color: #fefefe;
            margin: 10% auto;
            padding: 20px;
            border-radius: 8px;
            width: 50%;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
            position: relative;
        }

        .close {
            position: absolute;
            right: 20px;
            top: 15px;
            font-size: 28px;
            font-weight: bold;
            cursor: pointer;
        }

        .close:hover {
            color: #3498db;
        }

        /* 分析卡片和容器 */
        .analysis-container {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .analysis-card {
            flex: 1 1 300px;
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border: 1px solid #eaeaea;
        }

        .analysis-card h3 {
            margin-top: 0;
            color: #444;
            font-size: 16px;
            padding-bottom: 10px;
            border-bottom: 1px solid #f5f5f5;
            margin-bottom: 15px;
        }

        .analysis-card ul {
            margin: 0;
            padding-left: 20px;
        }

        .analysis-card li {
            margin-bottom: 8px;
            line-height: 1.5;
        }

        .check-form {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(220px, 1fr));
            gap: 15px;
            align-items: end;
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 6px;
            border: 1px solid #eee;
        }
    </style>

    <!-- 引入Chart.js -->
    <script src="https://cdn.bootcdn.net/ajax/libs/chart.js/3.7.0/chart.min.js"></script>
    <script>
        // 切换标签页
        function switchTab(tabId) {
            // 隐藏所有标签页内容
            const tabContents = document.querySelectorAll('.tab-content');
            tabContents.forEach(content => {
                content.classList.remove('active');
            });

            // 移除所有标签的active类
            const tabs = document.querySelectorAll('.tab');
            tabs.forEach(tab => {
                tab.classList.remove('active');
            });

            // 显示选中的标签页内容
            document.getElementById(tabId).classList.add('active');

            // 为当前标签添加active类
            const currentTabIndex = ['records-tab', 'settings-tab', 'alarms-tab', 'stats-tab'].indexOf(tabId);
            if (currentTabIndex >= 0) {
                tabs[currentTabIndex].classList.add('active');
            }
        }

        // 显示模态框
        function showModal(modalId) {
            document.getElementById(modalId).style.display = 'block';
        }

        // 隐藏模态框
        function hideModal(modalId) {
            document.getElementById(modalId).style.display = 'none';
        }

        // 处理报警
        function handleAlarm(alarmId) {
            document.getElementById('alarmId').value = alarmId;
            showModal('handleAlarmModal');
        }

        // 初始化温度图表
        const temperatureCtx = document.getElementById('temperatureChart')?.getContext('2d');
        if (temperatureCtx) {
            new Chart(temperatureCtx, {
                type: 'line',
                data: {
                    labels: <?= json_encode($chart_dates) ?>,
                    datasets: [{
                            label: '平均温度',
                            data: <?= json_encode(array_column($chart_temp_data, 'avg')) ?>,
                            borderColor: 'rgb(75, 192, 192)',
                            tension: 0.1
                        },
                        {
                            label: '最低温度',
                            data: <?= json_encode(array_column($chart_temp_data, 'min')) ?>,
                            borderColor: 'rgb(54, 162, 235)',
                            borderDash: [5, 5],
                            tension: 0.1
                        },
                        {
                            label: '最高温度',
                            data: <?= json_encode(array_column($chart_temp_data, 'max')) ?>,
                            borderColor: 'rgb(255, 99, 132)',
                            borderDash: [5, 5],
                            tension: 0.1
                        }
                    ]
                },
                options: {
                    responsive: true,
                    plugins: {
                        title: {
                            display: true,
                            text: '温度变化趋势'
                        }
                    },
                    scales: {
                        y: {
                            beginAtZero: false
                        }
                    }
                }
            });
        }

        // 初始化湿度图表
        <?php if ($selected_location && $selected_location['humidity_controlled']): ?>
            const humidityCtx = document.getElementById('humidityChart')?.getContext('2d');
            if (humidityCtx) {
                new Chart(humidityCtx, {
                    type: 'line',
                    data: {
                        labels: <?= json_encode($chart_dates) ?>,
                        datasets: [{
                                label: '平均湿度',
                                data: <?= json_encode(array_column($chart_humidity_data, 'avg')) ?>,
                                borderColor: 'rgb(75, 192, 192)',
                                tension: 0.1
                            },
                            {
                                label: '最低湿度',
                                data: <?= json_encode(array_column($chart_humidity_data, 'min')) ?>,
                                borderColor: 'rgb(54, 162, 235)',
                                borderDash: [5, 5],
                                tension: 0.1
                            },
                            {
                                label: '最高湿度',
                                data: <?= json_encode(array_column($chart_humidity_data, 'max')) ?>,
                                borderColor: 'rgb(255, 99, 132)',
                                borderDash: [5, 5],
                                tension: 0.1
                            }
                        ]
                    },
                    options: {
                        responsive: true,
                        plugins: {
                            title: {
                                display: true,
                                text: '湿度变化趋势'
                            }
                        },
                        scales: {
                            y: {
                                beginAtZero: false
                            }
                        }
                    }
                });
            }
        <?php endif; ?>
    </script>
</body>

</html>