<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';
$orders = [];

// 检查必要的表是否存在
try {
    // 检查shipments表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'shipments'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建发货表
            CREATE TABLE IF NOT EXISTS `shipments` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '发货ID',
              `shipment_number` VARCHAR(50) NOT NULL COMMENT '发货单号',
              `sales_order_id` INT UNSIGNED NOT NULL COMMENT '关联销售订单ID',
              `carrier_id` INT UNSIGNED DEFAULT NULL COMMENT '承运商ID',
              `tracking_number` VARCHAR(100) DEFAULT NULL COMMENT '物流单号',
              `shipment_date` DATETIME NOT NULL COMMENT '发货日期时间',
              `estimated_delivery_date` DATE DEFAULT NULL COMMENT '预计送达日期',
              `actual_delivery_date` DATETIME DEFAULT NULL COMMENT '实际送达日期时间',
              `shipping_cost` DECIMAL(10, 2) DEFAULT NULL COMMENT '物流费用',
              `status` ENUM(
                'pending',
                'ready_to_ship',
                'shipped',
                'in_transit',
                'delivered',
                'failed',
                'cancelled'
              ) NOT NULL DEFAULT 'pending' COMMENT '发货状态',
              `notes` TEXT DEFAULT NULL COMMENT '备注',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              UNIQUE KEY `uk_shipment_number` (`shipment_number`),
              KEY `idx_ship_order` (`sales_order_id`),
              KEY `idx_ship_carrier` (`carrier_id`),
              KEY `idx_ship_status` (`status`),
              KEY `idx_ship_date` (`shipment_date`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='发货记录表'
        ");

        // 创建承运商表
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `carriers` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '承运商ID',
              `name` VARCHAR(100) NOT NULL COMMENT '承运商名称',
              `service_type` VARCHAR(50) NOT NULL COMMENT '服务类型',
              `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
              `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
              `email` VARCHAR(100) DEFAULT NULL COMMENT '联系邮箱',
              `address` TEXT DEFAULT NULL COMMENT '地址',
              `website` VARCHAR(255) DEFAULT NULL COMMENT '网站',
              `tracking_url_template` VARCHAR(255) DEFAULT NULL COMMENT '物流跟踪URL模板',
              `is_active` TINYINT(1) NOT NULL DEFAULT 1 COMMENT '是否启用',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              KEY `idx_carrier_active` (`is_active`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='承运商表'
        ");

        // 添加示例承运商数据
        $pdo->exec("
            INSERT INTO `carriers` (`name`, `service_type`, `contact_person`, `phone`, `is_active`) VALUES
            ('顺丰速运', '快递', '客服中心', '95338', 1),
            ('中通快递', '快递', '客服中心', '95311', 1),
            ('圆通速递', '快递', '客服中心', '95554', 1),
            ('申通快递', '快递', '客服中心', '95543', 1),
            ('韵达速递', '快递', '客服中心', '95546', 1),
            ('京东物流', '快递', '客服中心', '950616', 1),
            ('德邦物流', '物流', '客服中心', '95353', 1),
            ('自提自运', '自运', '仓库管理员', '', 1)
        ");

        $success = "已创建发货记录表。";
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败: " . $e->getMessage();
}

// 获取查询参数
$tab = isset($_GET['tab']) ? $_GET['tab'] : 'pending';
$status = isset($_GET['status']) ? $_GET['status'] : '';
$keyword = isset($_GET['keyword']) ? trim($_GET['keyword']) : '';
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '';

// 处理订单状态更新
if (isset($_POST['update_status'])) {
    $order_id = isset($_POST['order_id']) ? (int)$_POST['order_id'] : 0;
    $new_status = isset($_POST['new_status']) ? $_POST['new_status'] : '';

    if (empty($order_id) || empty($new_status)) {
        $error = "缺少必要的参数";
    } else {
        try {
            $pdo->beginTransaction();

            // 更新订单状态
            $stmt = $pdo->prepare("UPDATE sales_orders SET status = ? WHERE id = ?");
            $stmt->execute([$new_status, $order_id]);

            // 记录操作日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                '更新订单状态',
                'order',
                $order_id,
                json_encode(['old_status' => $status, 'new_status' => $new_status]),
                $_SERVER['REMOTE_ADDR']
            ]);

            $pdo->commit();
            $success = "订单状态已更新为: " . $status_map[$new_status];
        } catch (PDOException $e) {
            $pdo->rollBack();
            $error = "更新订单状态失败: " . $e->getMessage();
        }
    }
}

// 处理创建发货单
if (isset($_POST['create_shipment'])) {
    $order_id = isset($_POST['order_id']) ? (int)$_POST['order_id'] : 0;
    $carrier_id = isset($_POST['carrier_id']) ? (int)$_POST['carrier_id'] : 0;
    $tracking_number = isset($_POST['tracking_number']) ? trim($_POST['tracking_number']) : '';
    $shipment_date = isset($_POST['shipment_date']) ? $_POST['shipment_date'] : date('Y-m-d H:i:s');
    $estimated_delivery_date = isset($_POST['estimated_delivery_date']) ? $_POST['estimated_delivery_date'] : '';
    $shipping_cost = isset($_POST['shipping_cost']) ? (float)$_POST['shipping_cost'] : 0;
    $notes = isset($_POST['shipment_notes']) ? trim($_POST['shipment_notes']) : '';

    if (empty($order_id) || empty($carrier_id)) {
        $error = "缺少必要的参数";
    } else {
        try {
            $pdo->beginTransaction();

            // 生成发货单号
            $shipment_number = 'SHIP-' . date('YmdHis');

            // 创建发货记录
            $stmt = $pdo->prepare("
                INSERT INTO shipments (
                    shipment_number, sales_order_id, carrier_id, tracking_number, 
                    shipment_date, estimated_delivery_date, shipping_cost, status, notes
                ) VALUES (?, ?, ?, ?, ?, ?, ?, 'shipped', ?)
            ");
            $stmt->execute([
                $shipment_number,
                $order_id,
                $carrier_id,
                $tracking_number,
                $shipment_date,
                $estimated_delivery_date,
                $shipping_cost,
                $notes
            ]);

            // 更新订单状态为已发货
            $stmt = $pdo->prepare("UPDATE sales_orders SET status = 'shipped' WHERE id = ?");
            $stmt->execute([$order_id]);

            // 记录操作日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                '创建发货单',
                'shipment',
                $pdo->lastInsertId(),
                json_encode([
                    'order_id' => $order_id,
                    'shipment_number' => $shipment_number,
                    'carrier_id' => $carrier_id
                ]),
                $_SERVER['REMOTE_ADDR']
            ]);

            $pdo->commit();
            $success = "发货单创建成功，单号: " . $shipment_number;
        } catch (PDOException $e) {
            $pdo->rollBack();
            $error = "创建发货单失败: " . $e->getMessage();
        }
    }
}

// 获取所有物流公司
try {
    $carriers = $pdo->query("SELECT id, name, service_type FROM carriers WHERE is_active = 1 ORDER BY name")->fetchAll();
} catch (PDOException $e) {
    $error = "获取物流公司失败: " . $e->getMessage();
}

// 获取订单数据 - 按当前标签页筛选
try {
    // 基础查询
    $baseQuery = "
        SELECT 
            so.id,
            so.order_number,
            so.order_date,
            so.required_date,
            so.total_amount,
            so.status,
            so.shipping_address,
            c.name AS customer_name,
            c.contact_person,
            c.phone,
            sc.name AS channel_name
        FROM 
            sales_orders so
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        LEFT JOIN 
            sales_channels sc ON so.sales_channel_id = sc.id
        WHERE 1=1
    ";

    $params = [];

    // 根据标签页添加状态过滤条件
    switch ($tab) {
        case 'pending':
            $baseQuery .= " AND so.status = 'confirmed'";
            break;
        case 'processing':
            $baseQuery .= " AND so.status = 'processing'";
            break;
        case 'shipping':
            $baseQuery .= " AND (so.status = 'processing' OR so.status = 'partially_shipped')";
            break;
        case 'completed':
            $baseQuery .= " AND (so.status = 'shipped' OR so.status = 'delivered')";
            break;
    }

    // 添加搜索条件
    if (!empty($keyword)) {
        $baseQuery .= " AND (so.order_number LIKE ? OR c.name LIKE ? OR so.shipping_address LIKE ?)";
        $searchTerm = "%$keyword%";
        $params[] = $searchTerm;
        $params[] = $searchTerm;
        $params[] = $searchTerm;
    }

    // 添加日期过滤条件
    if (!empty($date_from)) {
        $baseQuery .= " AND so.order_date >= ?";
        $params[] = $date_from . ' 00:00:00';
    }

    if (!empty($date_to)) {
        $baseQuery .= " AND so.order_date <= ?";
        $params[] = $date_to . ' 23:59:59';
    }

    // 添加排序条件
    $baseQuery .= " ORDER BY so.order_date DESC";

    // 执行查询
    $stmt = $pdo->prepare($baseQuery);
    $stmt->execute($params);
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取订单数据失败: " . $e->getMessage();
    $orders = [];
}

// 获取订单状态映射
$status_map = [
    'draft' => '草稿',
    'confirmed' => '已确认',
    'processing' => '处理中',
    'partially_shipped' => '部分发货',
    'shipped' => '已发货',
    'delivered' => '已送达',
    'cancelled' => '已取消'
];

// 首页先仅显示待处理的订单列表，其他部分将在下一个编辑中实现
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单处理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="date"],
        .form-group input[type="text"],
        .form-group input[type="number"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        .form-group textarea {
            resize: vertical;
            min-height: 80px;
        }

        .form-row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -10px;
            margin-left: -10px;
        }

        .form-col {
            flex: 1;
            padding: 0 10px;
            min-width: 200px;
        }

        /* 按钮样式 */
        .btn,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white !important;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            text-decoration: none !important;
            display: inline-block;
            transition: background 0.3s;
        }

        .btn:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        .btn-secondary {
            background: #6c757d;
        }

        .btn-secondary:hover {
            background: #5a6268;
        }

        .btn-success {
            background: #28a745;
        }

        .btn-success:hover {
            background: #218838;
        }

        .btn-danger {
            background: #dc3545;
        }

        .btn-danger:hover {
            background: #c82333;
        }

        .btn-edit,
        .btn-view,
        .btn-ship {
            display: inline-block !important;
            padding: 4px 8px !important;
            border-radius: 4px !important;
            color: white !important;
            text-decoration: none !important;
            margin: 2px !important;
            font-weight: normal !important;
        }

        .btn-edit {
            background: #17a2b8 !important;
        }

        .btn-view {
            background: #6c757d !important;
        }

        .btn-ship {
            background: #28a745 !important;
        }

        /* 表格样式 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left !important;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        /* 状态标签 */
        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            text-align: center;
        }

        .status-draft {
            background-color: #6c757d;
            color: white;
        }

        .status-confirmed {
            background-color: #007bff;
            color: white;
        }

        .status-processing {
            background-color: #17a2b8;
            color: white;
        }

        .status-partially_shipped {
            background-color: #fd7e14;
            color: white;
        }

        .status-shipped {
            background-color: #28a745;
            color: white;
        }

        .status-delivered {
            background-color: #20c997;
            color: white;
        }

        .status-cancelled {
            background-color: #dc3545;
            color: white;
        }

        /* 搜索表单 */
        .search-form {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            margin-bottom: 20px;
            align-items: flex-end;
        }

        .search-form .form-group {
            margin-bottom: 0;
            flex: 1;
            min-width: 150px;
        }

        .search-form .btn,
        .search-form .btn-secondary {
            height: 42px;
            margin-bottom: 0;
            line-height: 22px;
            display: flex;
            align-items: center;
            justify-content: center;
            min-width: 80px;
            padding: 0 15px;
            font-size: 14px;
            font-weight: bold;
        }

        /* 警告和成功消息 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 空状态 */
        .empty-state {
            text-align: center;
            padding: 40px 20px;
            background: #f8f9fa;
            border-radius: 8px;
            border: 1px dashed #ddd;
            color: #6c757d;
        }

        .empty-state p {
            margin: 0;
            font-size: 16px;
        }

        /* 模态对话框 */
        .modal {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
            z-index: 1000;
            overflow: auto;
        }

        .modal-content {
            background-color: #fefefe;
            margin: 10% auto;
            padding: 20px;
            border-radius: 8px;
            width: 80%;
            max-width: 600px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        .modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        .modal-header h3 {
            margin: 0;
            font-size: 20px;
        }

        .modal-close {
            cursor: pointer;
            font-size: 24px;
            color: #aaa;
        }

        .modal-close:hover {
            color: #000;
        }

        .modal-footer {
            border-top: 1px solid #eee;
            padding-top: 15px;
            margin-top: 20px;
            text-align: right;
        }

        .modal-footer .btn {
            margin-left: 10px;
        }

        /* 选项卡样式 */
        .tabs {
            display: flex;
            margin-bottom: 25px;
            border-bottom: 1px solid #ddd;
            background: white;
            border-radius: 8px 8px 0 0;
            overflow: hidden;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .tab {
            padding: 12px 20px;
            cursor: pointer;
            font-weight: bold;
            transition: all 0.3s;
            text-align: center;
            flex: 1;
            border-bottom: 3px solid transparent;
        }

        .tab:hover {
            background-color: #f8f9fa;
        }

        .tab.active {
            background: #3498db;
            color: white;
            border-bottom: 3px solid #2980b9;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
            animation: fadeIn 0.5s;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>订单处理中心</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <!-- 标签页导航 -->
        <div class="tabs">
            <div class="tab <?= empty($_GET['tab']) || $_GET['tab'] == 'pending' ? 'active' : '' ?>"
                onclick="location.href='order_processing.php?tab=pending'">待处理订单</div>
            <div class="tab <?= isset($_GET['tab']) && $_GET['tab'] == 'processing' ? 'active' : '' ?>"
                onclick="location.href='order_processing.php?tab=processing'">处理中订单</div>
            <div class="tab <?= isset($_GET['tab']) && $_GET['tab'] == 'shipping' ? 'active' : '' ?>"
                onclick="location.href='order_processing.php?tab=shipping'">发货管理</div>
            <div class="tab <?= isset($_GET['tab']) && $_GET['tab'] == 'completed' ? 'active' : '' ?>"
                onclick="location.href='order_processing.php?tab=completed'">已完成订单</div>
        </div>

        <!-- 待处理订单内容区 -->
        <div id="pending-orders" class="tab-content <?= empty($_GET['tab']) || $_GET['tab'] == 'pending' ? 'active' : '' ?>">
            <div class="section">
                <h2>待处理订单</h2>

                <!-- 搜索表单 -->
                <form class="search-form" method="GET" action="">
                    <input type="hidden" name="tab" value="pending">

                    <div class="form-group">
                        <label for="keyword">关键词搜索:</label>
                        <input type="text" id="keyword" name="keyword" value="<?= htmlspecialchars($keyword) ?>"
                            placeholder="订单号/客户名称/地址">
                    </div>

                    <div class="form-group">
                        <label for="date_from">订单日期从:</label>
                        <input type="date" id="date_from" name="date_from" value="<?= htmlspecialchars($date_from) ?>">
                    </div>

                    <div class="form-group">
                        <label for="date_to">订单日期至:</label>
                        <input type="date" id="date_to" name="date_to" value="<?= htmlspecialchars($date_to) ?>">
                    </div>

                    <button type="submit" class="btn">搜索</button>
                    <a href="order_processing.php?tab=pending" class="btn btn-secondary">重置</a>
                </form>

                <!-- 订单列表表格 -->
                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>订单日期</th>
                                <th>客户名称</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($orders)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">
                                        <div class="empty-state">
                                            <p>没有找到待处理订单</p>
                                        </div>
                                    </td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($order['order_number']) ?></td>
                                        <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                        <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                        <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                        <td>
                                            <span class="status-tag status-<?= $order['status'] ?>">
                                                <?= isset($status_map[$order['status']]) ? $status_map[$order['status']] : $order['status'] ?>
                                            </span>
                                        </td>
                                        <td>
                                            <a href="order_detail.php?id=<?= $order['id'] ?>" class="btn-view">查看</a>

                                            <?php if ($tab == 'pending'): ?>
                                                <form method="post" action="" style="display:inline;">
                                                    <input type="hidden" name="order_id" value="<?= $order['id'] ?>">
                                                    <input type="hidden" name="new_status" value="processing">
                                                    <button type="submit" name="update_status" class="btn-edit"
                                                        onclick="return confirm('确认开始处理此订单?')">开始处理</button>
                                                </form>
                                            <?php endif; ?>

                                            <?php if ($tab == 'processing'): ?>
                                                <button type="button" class="btn-ship"
                                                    onclick="openShipModal(<?= $order['id'] ?>, '<?= htmlspecialchars($order['order_number']) ?>')">
                                                    创建发货单
                                                </button>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- 处理中订单内容区 -->
        <div id="processing-orders" class="tab-content <?= isset($_GET['tab']) && $_GET['tab'] == 'processing' ? 'active' : '' ?>">
            <div class="section">
                <h2>处理中订单</h2>

                <!-- 搜索表单 -->
                <form class="search-form" method="GET" action="">
                    <input type="hidden" name="tab" value="processing">

                    <div class="form-group">
                        <label for="keyword">关键词搜索:</label>
                        <input type="text" id="keyword" name="keyword" value="<?= htmlspecialchars($keyword) ?>"
                            placeholder="订单号/客户名称/地址">
                    </div>

                    <div class="form-group">
                        <label for="date_from">订单日期从:</label>
                        <input type="date" id="date_from" name="date_from" value="<?= htmlspecialchars($date_from) ?>">
                    </div>

                    <div class="form-group">
                        <label for="date_to">订单日期至:</label>
                        <input type="date" id="date_to" name="date_to" value="<?= htmlspecialchars($date_to) ?>">
                    </div>

                    <button type="submit" class="btn">搜索</button>
                    <a href="order_processing.php?tab=processing" class="btn btn-secondary">重置</a>
                </form>

                <!-- 订单列表表格 -->
                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>订单日期</th>
                                <th>客户名称</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($orders) && $tab == 'processing'): ?>
                                <tr>
                                    <td colspan="6" class="text-center">
                                        <div class="empty-state">
                                            <p>没有找到处理中的订单</p>
                                        </div>
                                    </td>
                                </tr>
                            <?php elseif ($tab == 'processing'): ?>
                                <?php foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($order['order_number']) ?></td>
                                        <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                        <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                        <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                        <td>
                                            <span class="status-tag status-<?= $order['status'] ?>">
                                                <?= isset($status_map[$order['status']]) ? $status_map[$order['status']] : $order['status'] ?>
                                            </span>
                                        </td>
                                        <td>
                                            <a href="order_detail.php?id=<?= $order['id'] ?>" class="btn-view">查看</a>
                                            <button type="button" class="btn-ship"
                                                onclick="openShipModal(<?= $order['id'] ?>, '<?= htmlspecialchars($order['order_number']) ?>')">
                                                创建发货单
                                            </button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- 待发货订单内容区 -->
        <div id="shipping-orders" class="tab-content <?= isset($_GET['tab']) && $_GET['tab'] == 'shipping' ? 'active' : '' ?>">
            <div class="section">
                <h2>待发货订单</h2>

                <!-- 搜索表单 -->
                <form class="search-form" method="GET" action="">
                    <input type="hidden" name="tab" value="shipping">

                    <div class="form-group">
                        <label for="keyword">关键词搜索:</label>
                        <input type="text" id="keyword" name="keyword" value="<?= htmlspecialchars($keyword) ?>"
                            placeholder="订单号/客户名称/地址">
                    </div>

                    <div class="form-group">
                        <label for="date_from">订单日期从:</label>
                        <input type="date" id="date_from" name="date_from" value="<?= htmlspecialchars($date_from) ?>">
                    </div>

                    <div class="form-group">
                        <label for="date_to">订单日期至:</label>
                        <input type="date" id="date_to" name="date_to" value="<?= htmlspecialchars($date_to) ?>">
                    </div>

                    <button type="submit" class="btn">搜索</button>
                    <a href="order_processing.php?tab=shipping" class="btn btn-secondary">重置</a>
                </form>

                <!-- 订单列表表格 -->
                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>订单日期</th>
                                <th>客户名称</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($orders) && $tab == 'shipping'): ?>
                                <tr>
                                    <td colspan="6" class="text-center">
                                        <div class="empty-state">
                                            <p>没有找到待发货的订单</p>
                                        </div>
                                    </td>
                                </tr>
                            <?php elseif ($tab == 'shipping'): ?>
                                <?php foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($order['order_number']) ?></td>
                                        <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                        <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                        <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                        <td>
                                            <span class="status-tag status-<?= $order['status'] ?>">
                                                <?= isset($status_map[$order['status']]) ? $status_map[$order['status']] : $order['status'] ?>
                                            </span>
                                        </td>
                                        <td>
                                            <a href="order_detail.php?id=<?= $order['id'] ?>" class="btn-view">查看</a>
                                            <button type="button" class="btn-ship"
                                                onclick="openShipModal(<?= $order['id'] ?>, '<?= htmlspecialchars($order['order_number']) ?>')">
                                                创建发货单
                                            </button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- 已完成订单内容区 -->
        <div id="completed-orders" class="tab-content <?= isset($_GET['tab']) && $_GET['tab'] == 'completed' ? 'active' : '' ?>">
            <div class="section">
                <h2>已完成订单</h2>

                <!-- 搜索表单 -->
                <form class="search-form" method="GET" action="">
                    <input type="hidden" name="tab" value="completed">

                    <div class="form-group">
                        <label for="keyword">关键词搜索:</label>
                        <input type="text" id="keyword" name="keyword" value="<?= htmlspecialchars($keyword) ?>"
                            placeholder="订单号/客户名称/地址">
                    </div>

                    <div class="form-group">
                        <label for="date_from">订单日期从:</label>
                        <input type="date" id="date_from" name="date_from" value="<?= htmlspecialchars($date_from) ?>">
                    </div>

                    <div class="form-group">
                        <label for="date_to">订单日期至:</label>
                        <input type="date" id="date_to" name="date_to" value="<?= htmlspecialchars($date_to) ?>">
                    </div>

                    <button type="submit" class="btn">搜索</button>
                    <a href="order_processing.php?tab=completed" class="btn btn-secondary">重置</a>
                </form>

                <!-- 订单列表表格 -->
                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>订单日期</th>
                                <th>客户名称</th>
                                <th>金额</th>
                                <th>发货日期</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($orders) && $tab == 'completed'): ?>
                                <tr>
                                    <td colspan="7" class="text-center">
                                        <div class="empty-state">
                                            <p>没有找到已完成的订单</p>
                                        </div>
                                    </td>
                                </tr>
                            <?php elseif ($tab == 'completed'): ?>
                                <?php
                                // 为已完成订单获取相关的发货信息
                                try {
                                    $orderIds = array_column($orders, 'id');
                                    if (!empty($orderIds)) {
                                        $placeholders = implode(',', array_fill(0, count($orderIds), '?'));
                                        $shipmentStmt = $pdo->prepare("
                                                SELECT 
                                                    shipment_number, 
                                                    sales_order_id, 
                                                    shipment_date, 
                                                    tracking_number,
                                                    carrier_id
                                                FROM 
                                                    shipments 
                                                WHERE 
                                                    sales_order_id IN ($placeholders)
                                            ");
                                        $shipmentStmt->execute($orderIds);
                                        $shipments = $shipmentStmt->fetchAll(PDO::FETCH_GROUP | PDO::FETCH_ASSOC);
                                    }
                                } catch (PDOException $e) {
                                    $error = "获取发货数据失败: " . $e->getMessage();
                                    $shipments = [];
                                }
                                ?>
                                <?php foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($order['order_number']) ?></td>
                                        <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                        <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                        <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                        <td>
                                            <?php
                                            $shipmentDate = '未发货';
                                            if (isset($shipments[$order['id']]) && !empty($shipments[$order['id']][0]['shipment_date'])) {
                                                $shipmentDate = date('Y-m-d', strtotime($shipments[$order['id']][0]['shipment_date']));
                                            }
                                            echo $shipmentDate;
                                            ?>
                                        </td>
                                        <td>
                                            <span class="status-tag status-<?= $order['status'] ?>">
                                                <?= isset($status_map[$order['status']]) ? $status_map[$order['status']] : $order['status'] ?>
                                            </span>
                                        </td>
                                        <td>
                                            <a href="order_detail.php?id=<?= $order['id'] ?>" class="btn-view">查看</a>
                                            <?php if ($order['status'] == 'shipped'): ?>
                                                <form method="post" action="" style="display:inline;">
                                                    <input type="hidden" name="order_id" value="<?= $order['id'] ?>">
                                                    <input type="hidden" name="new_status" value="delivered">
                                                    <button type="submit" name="update_status" class="btn-success"
                                                        onclick="return confirm('确认将订单标记为已送达?')">标记为已送达</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- 发货模态框 -->
        <div id="ship-modal" class="modal">
            <div class="modal-content">
                <div class="modal-header">
                    <h3>创建发货单</h3>
                    <span class="modal-close" onclick="closeShipModal()">&times;</span>
                </div>

                <form method="POST" action="">
                    <input type="hidden" id="ship_order_id" name="order_id" value="">

                    <div class="form-group">
                        <label>订单号:</label>
                        <input type="text" id="ship_order_number" readonly>
                    </div>

                    <div class="form-row">
                        <div class="form-col">
                            <div class="form-group">
                                <label for="carrier_id">物流公司:</label>
                                <select id="carrier_id" name="carrier_id" required>
                                    <option value="">-- 选择物流公司 --</option>
                                    <?php foreach ($carriers as $carrier): ?>
                                        <option value="<?= $carrier['id'] ?>">
                                            <?= htmlspecialchars($carrier['name']) ?>
                                            (<?= htmlspecialchars($carrier['service_type']) ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>

                        <div class="form-col">
                            <div class="form-group">
                                <label for="tracking_number">物流单号:</label>
                                <input type="text" id="tracking_number" name="tracking_number">
                            </div>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-col">
                            <div class="form-group">
                                <label for="shipment_date">发货日期:</label>
                                <input type="datetime-local" id="shipment_date" name="shipment_date"
                                    value="<?= date('Y-m-d\TH:i') ?>" required>
                            </div>
                        </div>

                        <div class="form-col">
                            <div class="form-group">
                                <label for="estimated_delivery_date">预计送达日期:</label>
                                <input type="date" id="estimated_delivery_date" name="estimated_delivery_date"
                                    value="<?= date('Y-m-d', strtotime('+3 days')) ?>">
                            </div>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-col">
                            <div class="form-group">
                                <label for="shipping_cost">物流费用:</label>
                                <input type="number" id="shipping_cost" name="shipping_cost" step="0.01" min="0" value="0.00">
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="shipment_notes">备注:</label>
                        <textarea id="shipment_notes" name="shipment_notes" rows="3"></textarea>
                    </div>

                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" onclick="closeShipModal()">取消</button>
                        <button type="submit" name="create_shipment" class="btn btn-primary">创建发货单</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
        // 打开发货模态框
        function openShipModal(orderId, orderNumber) {
            document.getElementById('ship_order_id').value = orderId;
            document.getElementById('ship_order_number').value = orderNumber;
            document.getElementById('ship-modal').style.display = 'block';
        }

        // 关闭发货模态框
        function closeShipModal() {
            document.getElementById('ship-modal').style.display = 'none';
        }

        // 点击模态框外部关闭模态框
        window.onclick = function(event) {
            const modal = document.getElementById('ship-modal');
            if (event.target == modal) {
                closeShipModal();
            }
        }
    </script>
</body>

</html>