<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';

// 获取时间范围参数
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$custom_from = isset($_GET['custom_from']) ? $_GET['custom_from'] : date('Y-m-d', strtotime('-30 days'));
$custom_to = isset($_GET['custom_to']) ? $_GET['custom_to'] : date('Y-m-d');
$sales_channel_id = isset($_GET['sales_channel_id']) ? (int)$_GET['sales_channel_id'] : 0;

// 设置日期范围
switch ($date_range) {
    case 'week':
        $date_from = date('Y-m-d', strtotime('-7 days'));
        $date_to = date('Y-m-d');
        $date_title = '最近7天';
        break;
    case 'month':
        $date_from = date('Y-m-d', strtotime('-30 days'));
        $date_to = date('Y-m-d');
        $date_title = '最近30天';
        break;
    case 'quarter':
        $date_from = date('Y-m-d', strtotime('-90 days'));
        $date_to = date('Y-m-d');
        $date_title = '最近90天';
        break;
    case 'year':
        $date_from = date('Y-m-d', strtotime('-365 days'));
        $date_to = date('Y-m-d');
        $date_title = '最近1年';
        break;
    case 'custom':
        $date_from = $custom_from;
        $date_to = $custom_to;
        $date_title = date('Y-m-d', strtotime($custom_from)) . ' 至 ' . date('Y-m-d', strtotime($custom_to));
        break;
    default:
        $date_from = date('Y-m-d', strtotime('-30 days'));
        $date_to = date('Y-m-d');
        $date_title = '最近30天';
        break;
}

// 获取所有销售渠道
try {
    $stmt = $pdo->query("SELECT id, name FROM sales_channels ORDER BY name");
    $sales_channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售渠道失败: " . $e->getMessage();
    $sales_channels = [];
}

// 获取销售总览数据
$sales_overview = [];
try {
    $query = "
        SELECT 
            COUNT(*) AS total_orders,
            SUM(total_amount) AS total_sales,
            AVG(total_amount) AS avg_order_value,
            COUNT(DISTINCT customer_id) AS customer_count
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $sales_overview = $stmt->fetch();
} catch (PDOException $e) {
    $error = "获取销售总览数据失败: " . $e->getMessage();
}

// 按时间维度统计销售额
$time_series_data = [];
try {
    // 根据时间范围选择适当的时间分组(按日、周、月)
    if ($date_range == 'week' || $date_range == 'custom' && strtotime($date_to) - strtotime($date_from) <= 7 * 24 * 60 * 60) {
        // 按天统计
        $time_grouping = "DATE_FORMAT(order_date, '%Y-%m-%d')";
        $time_format = "日期";
    } elseif ($date_range == 'month' || ($date_range == 'custom' && strtotime($date_to) - strtotime($date_from) <= 90 * 24 * 60 * 60)) {
        // 按天统计
        $time_grouping = "DATE_FORMAT(order_date, '%Y-%m-%d')";
        $time_format = "日期";
    } elseif ($date_range == 'quarter' || ($date_range == 'custom' && strtotime($date_to) - strtotime($date_from) <= 180 * 24 * 60 * 60)) {
        // 按周统计
        $time_grouping = "YEARWEEK(order_date, 1)";
        $time_format = "周次";
    } else {
        // 按月统计
        $time_grouping = "DATE_FORMAT(order_date, '%Y-%m')";
        $time_format = "月份";
    }

    $query = "
        SELECT 
            {$time_grouping} AS time_period,
            COUNT(*) AS order_count,
            SUM(total_amount) AS sales_amount
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    // 修复GROUP BY，确保使用与SELECT相同的表达式
    $query .= " GROUP BY {$time_grouping} ORDER BY {$time_grouping}";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $time_series_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售时间趋势数据失败: " . $e->getMessage();
}

// 按销售渠道统计销售额
$channel_data = [];
try {
    $query = "
        SELECT 
            sc.id AS channel_id,
            sc.name AS channel_name,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS sales_amount,
            AVG(so.total_amount) AS avg_order_value
        FROM 
            sales_orders so
        JOIN 
            sales_channels sc ON so.sales_channel_id = sc.id
        WHERE 
            so.order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND so.sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $query .= " GROUP BY sc.id, sc.name ORDER BY sales_amount DESC";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $channel_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售渠道数据失败: " . $e->getMessage();
}

// 获取产品销量排行
$product_ranking = [];
try {
    $query = "
        SELECT 
            p.id,
            p.name AS product_name,
            p.specification,
            SUM(soi.quantity) AS total_quantity,
            SUM(soi.item_total_amount) AS total_amount
        FROM 
            sales_order_items soi
        JOIN 
            products p ON soi.product_id = p.id
        JOIN 
            sales_orders so ON soi.sales_order_id = so.id
        WHERE 
            so.order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND so.sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $query .= " GROUP BY p.id, p.name, p.specification ORDER BY total_amount DESC LIMIT 10";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $product_ranking = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取产品销量排行数据失败: " . $e->getMessage();
}

// 获取客户订单统计
$customer_data = [];
try {
    $query = "
        SELECT 
            c.id,
            c.name AS customer_name,
            c.contact_person,
            c.type,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS total_amount,
            MAX(so.order_date) AS latest_order_date
        FROM 
            customers c
        JOIN 
            sales_orders so ON c.id = so.customer_id
        WHERE 
            so.order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND so.sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $query .= " GROUP BY c.id, c.name, c.contact_person, c.type ORDER BY total_amount DESC LIMIT 10";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $customer_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取客户订单统计数据失败: " . $e->getMessage();
}

// 客户类型映射
$customer_type_map = [
    'wholesale' => '批发',
    'retail' => '零售',
    'distributor' => '分销',
    'ecommerce' => '电商'
];

// 准备图表数据 - 销售趋势
$trend_labels = [];
$trend_values = [];
foreach ($time_series_data as $item) {
    $trend_labels[] = $item['time_period'];
    $trend_values[] = floatval($item['sales_amount']);
}
$trend_chart_data = [
    'labels' => json_encode($trend_labels),
    'values' => json_encode($trend_values)
];

// 准备图表数据 - 销售渠道占比
$channel_labels = [];
$channel_values = [];
foreach ($channel_data as $item) {
    $channel_labels[] = $item['channel_name'];
    $channel_values[] = floatval($item['sales_amount']);
}
$channel_chart_data = [
    'labels' => json_encode($channel_labels),
    'values' => json_encode($channel_values)
];

// 准备图表数据 - 产品销量对比
$product_labels = [];
$product_values = [];
foreach ($product_ranking as $item) {
    $product_labels[] = $item['product_name'];
    $product_values[] = floatval($item['total_quantity']);
}
$product_chart_data = [
    'labels' => json_encode($product_labels),
    'values' => json_encode($product_values)
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售统计分析 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <!-- 引入Chart.js图表库 -->
    <script src="https://cdn.bootcdn.net/ajax/libs/chart.js/3.9.1/chart.min.js"></script>
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 筛选表单样式 */
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
            margin-bottom: 20px;
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 6px;
            border: 1px solid #eee;
        }

        .filter-form .form-group {
            margin-bottom: 0;
            flex: 1;
            min-width: 200px;
        }

        .filter-form label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .filter-form select,
        .filter-form input[type="date"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 14px;
        }

        .filter-form button {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            min-width: 80px;
        }

        .filter-form button:hover {
            background: #2980b9;
        }

        /* 统计卡片样式 */
        .stats-container {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .stat-card {
            flex: 1;
            min-width: 200px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            text-align: center;
            transition: all 0.3s ease;
        }

        .stat-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
        }

        .stat-value {
            font-size: 28px;
            font-weight: bold;
            color: #3498db;
            margin: 10px 0;
        }

        .stat-label {
            color: #555;
            font-size: 14px;
            font-weight: bold;
        }

        /* 图表容器样式 */
        .chart-container {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .chart-container h3 {
            margin-top: 0;
            font-size: 16px;
            color: #444;
            padding-bottom: 10px;
            border-bottom: 1px solid #f5f5f5;
            margin-bottom: 15px;
        }

        .chart {
            width: 100%;
            height: 300px;
        }

        /* 表格样式优化 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        /* 警告和成功消息 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 选项卡样式 */
        .tabs {
            display: flex;
            margin-bottom: 25px;
            border-bottom: 1px solid #ddd;
            background: white;
            border-radius: 8px 8px 0 0;
            overflow: hidden;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .tab {
            padding: 12px 20px;
            cursor: pointer;
            font-weight: bold;
            transition: all 0.3s;
            text-align: center;
            flex: 1;
            border-bottom: 3px solid transparent;
        }

        .tab:hover {
            background-color: #f8f9fa;
        }

        .tab.active {
            background: #3498db;
            color: white;
            border-bottom: 3px solid #2980b9;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
            animation: fadeIn 0.5s;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }

        /* 数据比较标签 */
        .comparison {
            font-size: 12px;
            padding: 2px 5px;
            border-radius: 3px;
            margin-left: 5px;
        }

        .increase {
            color: #28a745;
        }

        .decrease {
            color: #dc3545;
        }

        /* 空状态样式 */
        .empty-state {
            text-align: center;
            padding: 40px 20px;
            background: #f8f9fa;
            border-radius: 8px;
            border: 1px dashed #ddd;
            color: #6c757d;
        }

        .empty-state p {
            margin: 0;
            font-size: 16px;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>销售统计分析</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <!-- 筛选条件 -->
        <div class="section">
            <h2>数据筛选</h2>
            <form method="GET" action="" class="filter-form">
                <div class="form-group">
                    <label for="date_range">时间范围:</label>
                    <select id="date_range" name="date_range" onchange="toggleCustomDate()">
                        <option value="week" <?= $date_range == 'week' ? 'selected' : '' ?>>最近7天</option>
                        <option value="month" <?= $date_range == 'month' ? 'selected' : '' ?>>最近30天</option>
                        <option value="quarter" <?= $date_range == 'quarter' ? 'selected' : '' ?>>最近90天</option>
                        <option value="year" <?= $date_range == 'year' ? 'selected' : '' ?>>最近1年</option>
                        <option value="custom" <?= $date_range == 'custom' ? 'selected' : '' ?>>自定义日期范围</option>
                    </select>
                </div>

                <div id="custom_date_container" class="form-group" style="<?= $date_range == 'custom' ? '' : 'display: none;' ?>">
                    <label for="custom_from">自定义开始日期:</label>
                    <input type="date" id="custom_from" name="custom_from" value="<?= $custom_from ?>">
                </div>

                <div id="custom_date_to_container" class="form-group" style="<?= $date_range == 'custom' ? '' : 'display: none;' ?>">
                    <label for="custom_to">自定义结束日期:</label>
                    <input type="date" id="custom_to" name="custom_to" value="<?= $custom_to ?>">
                </div>

                <div class="form-group">
                    <label for="sales_channel_id">销售渠道:</label>
                    <select id="sales_channel_id" name="sales_channel_id">
                        <option value="0">全部渠道</option>
                        <?php foreach ($sales_channels as $channel): ?>
                            <option value="<?= $channel['id'] ?>" <?= $sales_channel_id == $channel['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($channel['name']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit">应用筛选</button>
            </form>
        </div>

        <!-- 销售总览 -->
        <div class="stats-container">
            <div class="stat-card">
                <div class="stat-label">总订单数</div>
                <div class="stat-value"><?= number_format($sales_overview['total_orders'] ?? 0) ?></div>
                <div class="stat-label">笔</div>
            </div>

            <div class="stat-card">
                <div class="stat-label">总销售额</div>
                <div class="stat-value">¥<?= number_format(($sales_overview['total_sales'] ?? 0), 2) ?></div>
                <div class="stat-label"><?= $date_title ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-label">平均订单金额</div>
                <div class="stat-value">¥<?= number_format(($sales_overview['avg_order_value'] ?? 0), 2) ?></div>
                <div class="stat-label">元/订单</div>
            </div>

            <div class="stat-card">
                <div class="stat-label">下单客户数</div>
                <div class="stat-value"><?= number_format($sales_overview['customer_count'] ?? 0) ?></div>
                <div class="stat-label">个客户</div>
            </div>
        </div>

        <!-- 销售统计选项卡 -->
        <div class="tabs">
            <div class="tab active" onclick="switchTab('sales-analysis')">销售额分析</div>
            <div class="tab" onclick="switchTab('product-ranking')">产品销量排行</div>
            <div class="tab" onclick="switchTab('customer-analysis')">客户订单统计</div>
        </div>

        <!-- 销售额分析 -->
        <div id="sales-analysis" class="tab-content active">
            <!-- 销售趋势图表 -->
            <div class="chart-container">
                <h3>销售趋势 - <?= $date_title ?></h3>
                <canvas id="salesTrendChart" class="chart"></canvas>
            </div>

            <!-- 按销售渠道分析 -->
            <div class="section">
                <h2>渠道销售分析</h2>

                <div style="display: flex; flex-wrap: wrap; gap: 20px;">
                    <div style="flex: 2; min-width: 300px;">
                        <div class="table-container">
                            <?php if (empty($channel_data)): ?>
                                <div class="empty-state">
                                    <p>该时间段内没有销售渠道数据</p>
                                </div>
                            <?php else: ?>
                                <table>
                                    <thead>
                                        <tr>
                                            <th>销售渠道</th>
                                            <th>订单数量</th>
                                            <th>销售额 (¥)</th>
                                            <th>平均订单金额 (¥)</th>
                                            <th>占比</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        $total_amount = array_sum(array_column($channel_data, 'sales_amount'));
                                        foreach ($channel_data as $channel):
                                            $percentage = $total_amount > 0 ? ($channel['sales_amount'] / $total_amount * 100) : 0;
                                        ?>
                                            <tr>
                                                <td><?= htmlspecialchars($channel['channel_name']) ?></td>
                                                <td><?= number_format($channel['order_count']) ?></td>
                                                <td><?= number_format($channel['sales_amount'], 2) ?></td>
                                                <td><?= number_format($channel['avg_order_value'], 2) ?></td>
                                                <td><?= number_format($percentage, 2) ?>%</td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div style="flex: 1; min-width: 300px;">
                        <div style="height: 300px;">
                            <canvas id="channelPieChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 按时间维度分析 -->
            <div class="section">
                <h2>销售时间分布</h2>
                <div class="table-container">
                    <?php if (empty($time_series_data)): ?>
                        <div class="empty-state">
                            <p>该时间段内没有销售数据</p>
                        </div>
                    <?php else: ?>
                        <table>
                            <thead>
                                <tr>
                                    <th><?= $time_format ?></th>
                                    <th>订单数量</th>
                                    <th>销售额 (¥)</th>
                                    <th>日均销售额 (¥)</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($time_series_data as $item): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($item['time_period']) ?></td>
                                        <td><?= number_format($item['order_count']) ?></td>
                                        <td><?= number_format($item['sales_amount'], 2) ?></td>
                                        <td><?= number_format($item['sales_amount'] / $item['order_count'], 2) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- 产品销量排行 -->
        <div id="product-ranking" class="tab-content">
            <div class="section">
                <h2>产品销量排行 TOP 10</h2>

                <div style="display: flex; flex-wrap: wrap; gap: 20px;">
                    <div style="flex: 2; min-width: 300px;">
                        <div class="table-container">
                            <?php if (empty($product_ranking)): ?>
                                <div class="empty-state">
                                    <p>该时间段内没有产品销售数据</p>
                                </div>
                            <?php else: ?>
                                <table>
                                    <thead>
                                        <tr>
                                            <th>排名</th>
                                            <th>产品名称</th>
                                            <th>规格</th>
                                            <th>销售数量</th>
                                            <th>销售额 (¥)</th>
                                            <th>占比</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        $total_product_amount = array_sum(array_column($product_ranking, 'total_amount'));
                                        foreach ($product_ranking as $index => $product):
                                            $percentage = $total_product_amount > 0 ? ($product['total_amount'] / $total_product_amount * 100) : 0;
                                        ?>
                                            <tr>
                                                <td><?= $index + 1 ?></td>
                                                <td><?= htmlspecialchars($product['product_name']) ?></td>
                                                <td><?= htmlspecialchars($product['specification'] ?: '-') ?></td>
                                                <td><?= number_format($product['total_quantity'], 2) ?></td>
                                                <td><?= number_format($product['total_amount'], 2) ?></td>
                                                <td><?= number_format($percentage, 2) ?>%</td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div style="flex: 1; min-width: 300px;">
                        <div style="height: 400px;">
                            <canvas id="productBarChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- 客户订单统计 -->
        <div id="customer-analysis" class="tab-content">
            <div class="section">
                <h2>客户消费TOP 10</h2>
                <div class="table-container">
                    <?php if (empty($customer_data)): ?>
                        <div class="empty-state">
                            <p>该时间段内没有客户订单数据</p>
                        </div>
                    <?php else: ?>
                        <table>
                            <thead>
                                <tr>
                                    <th>排名</th>
                                    <th>客户名称</th>
                                    <th>联系人</th>
                                    <th>客户类型</th>
                                    <th>订单数量</th>
                                    <th>消费金额 (¥)</th>
                                    <th>最近下单日期</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($customer_data as $index => $customer): ?>
                                    <tr>
                                        <td><?= $index + 1 ?></td>
                                        <td><?= htmlspecialchars($customer['customer_name']) ?></td>
                                        <td><?= htmlspecialchars($customer['contact_person'] ?: '-') ?></td>
                                        <td><?= isset($customer_type_map[$customer['type']]) ? $customer_type_map[$customer['type']] : $customer['type'] ?></td>
                                        <td><?= number_format($customer['order_count']) ?></td>
                                        <td><?= number_format($customer['total_amount'], 2) ?></td>
                                        <td><?= date('Y-m-d', strtotime($customer['latest_order_date'])) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>

            <!-- 按客户类型分析 -->
            <?php
            // 计算客户类型分布
            $customer_type_distribution = [];
            $customer_type_totals = [];

            foreach ($customer_data as $customer) {
                $type = $customer['type'];
                if (!isset($customer_type_totals[$type])) {
                    $customer_type_totals[$type] = [
                        'type' => $type,
                        'type_name' => isset($customer_type_map[$type]) ? $customer_type_map[$type] : $type,
                        'count' => 0,
                        'amount' => 0
                    ];
                }

                $customer_type_totals[$type]['count'] += $customer['order_count'];
                $customer_type_totals[$type]['amount'] += $customer['total_amount'];
            }

            $customer_type_distribution = array_values($customer_type_totals);

            // 准备图表数据
            $customer_type_labels = [];
            $customer_type_values = [];

            foreach ($customer_type_distribution as $type) {
                $customer_type_labels[] = $type['type_name'];
                $customer_type_values[] = floatval($type['amount']);
            }
            ?>

            <div class="section">
                <h2>客户类型分析</h2>
                <div style="display: flex; flex-wrap: wrap; gap: 20px;">
                    <div style="flex: 1; min-width: 300px;">
                        <div class="table-container">
                            <?php if (empty($customer_type_distribution)): ?>
                                <div class="empty-state">
                                    <p>该时间段内没有客户类型分析数据</p>
                                </div>
                            <?php else: ?>
                                <table>
                                    <thead>
                                        <tr>
                                            <th>客户类型</th>
                                            <th>订单数量</th>
                                            <th>消费金额 (¥)</th>
                                            <th>占比</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        $total_type_amount = array_sum(array_column($customer_type_distribution, 'amount'));
                                        foreach ($customer_type_distribution as $type):
                                            $percentage = $total_type_amount > 0 ? ($type['amount'] / $total_type_amount * 100) : 0;
                                        ?>
                                            <tr>
                                                <td><?= htmlspecialchars($type['type_name']) ?></td>
                                                <td><?= number_format($type['count']) ?></td>
                                                <td><?= number_format($type['amount'], 2) ?></td>
                                                <td><?= number_format($percentage, 2) ?>%</td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div style="flex: 1; min-width: 300px;">
                        <div style="height: 300px;">
                            <canvas id="customerTypePieChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 初始化图表
        document.addEventListener('DOMContentLoaded', function() {
            // 切换自定义日期输入框
            window.toggleCustomDate = function() {
                const dateRange = document.getElementById('date_range').value;
                const customDateContainer = document.getElementById('custom_date_container');
                const customDateToContainer = document.getElementById('custom_date_to_container');

                if (dateRange === 'custom') {
                    customDateContainer.style.display = 'block';
                    customDateToContainer.style.display = 'block';
                } else {
                    customDateContainer.style.display = 'none';
                    customDateToContainer.style.display = 'none';
                }
            };

            // 切换选项卡
            window.switchTab = function(tabId) {
                // 隐藏所有选项卡内容
                document.querySelectorAll('.tab-content').forEach(function(tab) {
                    tab.classList.remove('active');
                });

                // 移除所有选项卡的活动状态
                document.querySelectorAll('.tab').forEach(function(tab) {
                    tab.classList.remove('active');
                });

                // 显示点击的选项卡内容
                document.getElementById(tabId).classList.add('active');

                // 设置点击的选项卡为活动状态
                const activeTab = Array.from(document.querySelectorAll('.tab')).find(tab =>
                    tab.getAttribute('onclick').includes(tabId)
                );
                if (activeTab) {
                    activeTab.classList.add('active');
                }
            };

            // 销售趋势图表
            const trendCtx = document.getElementById('salesTrendChart').getContext('2d');
            new Chart(trendCtx, {
                type: 'line',
                data: {
                    labels: <?= $trend_chart_data['labels'] ?>,
                    datasets: [{
                        label: '销售额',
                        data: <?= $trend_chart_data['values'] ?>,
                        backgroundColor: 'rgba(52, 152, 219, 0.3)',
                        borderColor: 'rgba(52, 152, 219, 1)',
                        borderWidth: 2,
                        pointBackgroundColor: 'rgba(52, 152, 219, 1)',
                        tension: 0.3
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true,
                            ticks: {
                                callback: function(value) {
                                    return '¥' + value.toLocaleString();
                                }
                            }
                        }
                    },
                    plugins: {
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    return '销售额: ¥' + context.raw.toLocaleString();
                                }
                            }
                        }
                    }
                }
            });

            // 销售渠道占比图表
            const channelCtx = document.getElementById('channelPieChart').getContext('2d');
            new Chart(channelCtx, {
                type: 'pie',
                data: {
                    labels: <?= $channel_chart_data['labels'] ?>,
                    datasets: [{
                        data: <?= $channel_chart_data['values'] ?>,
                        backgroundColor: [
                            'rgba(52, 152, 219, 0.7)',
                            'rgba(46, 204, 113, 0.7)',
                            'rgba(155, 89, 182, 0.7)',
                            'rgba(241, 196, 15, 0.7)',
                            'rgba(230, 126, 34, 0.7)'
                        ],
                        borderColor: [
                            'rgba(52, 152, 219, 1)',
                            'rgba(46, 204, 113, 1)',
                            'rgba(155, 89, 182, 1)',
                            'rgba(241, 196, 15, 1)',
                            'rgba(230, 126, 34, 1)'
                        ],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            position: 'right'
                        },
                        title: {
                            display: true,
                            text: '销售渠道占比'
                        },
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    const label = context.label || '';
                                    const value = context.raw;
                                    const total = context.dataset.data.reduce((a, b) => a + b, 0);
                                    const percentage = ((value / total) * 100).toFixed(2) + '%';
                                    return label + ': ¥' + value.toLocaleString() + ' (' + percentage + ')';
                                }
                            }
                        }
                    }
                }
            });

            // 产品销量图表
            const productCtx = document.getElementById('productBarChart').getContext('2d');
            new Chart(productCtx, {
                type: 'bar',
                data: {
                    labels: <?= $product_chart_data['labels'] ?>,
                    datasets: [{
                        label: '销售数量',
                        data: <?= $product_chart_data['values'] ?>,
                        backgroundColor: 'rgba(46, 204, 113, 0.7)',
                        borderColor: 'rgba(46, 204, 113, 1)',
                        borderWidth: 1
                    }]
                },
                options: {
                    indexAxis: 'y',
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            display: false
                        },
                        title: {
                            display: true,
                            text: '产品销量排行'
                        }
                    }
                }
            });

            // 客户类型占比图表
            const customerTypeCtx = document.getElementById('customerTypePieChart').getContext('2d');
            new Chart(customerTypeCtx, {
                type: 'doughnut',
                data: {
                    labels: <?= json_encode($customer_type_labels) ?>,
                    datasets: [{
                        data: <?= json_encode($customer_type_values) ?>,
                        backgroundColor: [
                            'rgba(52, 152, 219, 0.7)',
                            'rgba(46, 204, 113, 0.7)',
                            'rgba(155, 89, 182, 0.7)',
                            'rgba(241, 196, 15, 0.7)'
                        ],
                        borderColor: [
                            'rgba(52, 152, 219, 1)',
                            'rgba(46, 204, 113, 1)',
                            'rgba(155, 89, 182, 1)',
                            'rgba(241, 196, 15, 1)'
                        ],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            position: 'right'
                        },
                        title: {
                            display: true,
                            text: '客户类型销售额占比'
                        },
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    const label = context.label || '';
                                    const value = context.raw;
                                    const total = context.dataset.data.reduce((a, b) => a + b, 0);
                                    const percentage = ((value / total) * 100).toFixed(2) + '%';
                                    return label + ': ¥' + value.toLocaleString() + ' (' + percentage + ')';
                                }
                            }
                        }
                    }
                }
            });
        });
    </script>
</body>

</html>