<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// CSRF验证
if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
    $_SESSION['error'] = "安全验证失败，请重试";
    header("Location: purchase_orders.php");
    exit;
}

// 验证必填字段
$required_fields = ['supplier_id', 'order_date', 'expected_delivery_date'];
foreach ($required_fields as $field) {
    if (!isset($_POST[$field]) || trim($_POST[$field]) === '') {
        $_SESSION['error'] = "{$field}是必填项";
        header("Location: purchase_orders.php");
        exit;
    }
}

try {
    $pdo->beginTransaction();

    // 获取表单数据
    $supplier_id = (int)$_POST['supplier_id'];
    $order_date = $_POST['order_date'];
    $expected_delivery_date = $_POST['expected_delivery_date'];
    $notes = trim($_POST['notes'] ?? '');

    // 生成订单编号
    $order_number = 'PO' . date('Ymd') . sprintf('%03d', rand(1, 999));

    // 创建采购订单
    $stmt = $pdo->prepare("
        INSERT INTO purchase_orders (
            order_number, 
            supplier_id, 
            order_date, 
            expected_delivery_date, 
            status, 
            created_by_user_id
        ) VALUES (?, ?, ?, ?, 'pending', ?)
    ");
    $stmt->execute([
        $order_number,
        $supplier_id,
        $order_date,
        $expected_delivery_date,
        $_SESSION['user_id']
    ]);

    $purchase_order_id = $pdo->lastInsertId();

    // 处理订单项
    $total_amount = 0;

    // 假设订单项数据以数组形式提交
    $product_ids = $_POST['product_id'] ?? [];
    $quantities = $_POST['quantity'] ?? [];
    $unit_prices = $_POST['unit_price'] ?? [];

    for ($i = 0; $i < count($product_ids); $i++) {
        if (empty($product_ids[$i]) || empty($quantities[$i]) || empty($unit_prices[$i])) {
            continue; // 跳过空项
        }

        $product_id = (int)$product_ids[$i];
        $quantity = (float)$quantities[$i];
        $unit_price = (float)$unit_prices[$i];
        $item_total = $quantity * $unit_price;
        $total_amount += $item_total;

        $stmt = $pdo->prepare("
            INSERT INTO purchase_order_items (
                purchase_order_id,
                product_id,
                quantity,
                unit_price,
                received_quantity
            ) VALUES (?, ?, ?, ?, 0)
        ");
        $stmt->execute([
            $purchase_order_id,
            $product_id,
            $quantity,
            $unit_price
        ]);
    }

    // 更新订单总金额
    $stmt = $pdo->prepare("
        UPDATE purchase_orders 
        SET total_amount = ? 
        WHERE id = ?
    ");
    $stmt->execute([$total_amount, $purchase_order_id]);

    // 记录操作日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '创建采购订单',
        'purchase_order',
        $purchase_order_id,
        json_encode([
            'order_number' => $order_number,
            'supplier_id' => $supplier_id,
            'total_amount' => $total_amount
        ]),
        $_SERVER['REMOTE_ADDR']
    ]);

    $pdo->commit();
    $_SESSION['success'] = "采购订单已创建成功，订单编号：{$order_number}";
    header("Location: purchase_orders.php");
    exit;
} catch (PDOException $e) {
    $pdo->rollBack();
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
    header("Location: purchase_orders.php");
    exit;
} catch (Exception $e) {
    $pdo->rollBack();
    $_SESSION['error'] = $e->getMessage();
    header("Location: purchase_orders.php");
    exit;
}
