<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header("Location: user_management.php");
    exit;
}

// 验证CSRF Token
if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
    $_SESSION['error'] = "安全验证失败，请重试";
    header("Location: user_management.php");
    exit;
}

// 获取表单数据
$username = trim($_POST['username'] ?? '');
$password = $_POST['password'] ?? '';
$full_name = trim($_POST['full_name'] ?? '');
$email = trim($_POST['email'] ?? '');
$phone = trim($_POST['phone'] ?? '');
$role_id = (int)($_POST['role_id'] ?? 0);

// 验证数据
if (empty($username) || empty($password) || $role_id <= 0) {
    $_SESSION['error'] = "必填字段不能为空";
    header("Location: user_management.php");
    exit;
}

try {
    $pdo->beginTransaction();

    // 检查用户名是否已存在
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE username = ?");
    $stmt->execute([$username]);
    if ($stmt->fetchColumn() > 0) {
        throw new Exception("用户名 '$username' 已存在");
    }

    // 检查邮箱是否已存在
    if (!empty($email)) {
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE email = ? AND email IS NOT NULL");
        $stmt->execute([$email]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception("邮箱 '$email' 已被使用");
        }
    }

    // 检查手机号是否已存在
    if (!empty($phone)) {
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE phone = ? AND phone IS NOT NULL");
        $stmt->execute([$phone]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception("手机号 '$phone' 已被使用");
        }
    }

    // 检查角色是否存在
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM roles WHERE id = ?");
    $stmt->execute([$role_id]);
    if ($stmt->fetchColumn() == 0) {
        throw new Exception("选择的角色不存在");
    }

    // 创建用户
    $password_hash = password_hash($password, PASSWORD_DEFAULT);

    $stmt = $pdo->prepare("
        INSERT INTO users 
        (username, password_hash, full_name, email, phone, role_id, is_active, created_at, updated_at) 
        VALUES (?, ?, ?, ?, ?, ?, 1, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP)
    ");

    $stmt->execute([
        $username,
        $password_hash,
        $full_name ?: null,
        $email ?: null,
        $phone ?: null,
        $role_id
    ]);

    $user_id = $pdo->lastInsertId();

    // 记录日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");

    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '创建用户',
        'user',
        $user_id,
        json_encode([
            'username' => $username,
            'role_id' => $role_id,
            'created_by' => $_SESSION['user_id']
        ]),
        $_SERVER['REMOTE_ADDR']
    ]);

    $pdo->commit();
    $_SESSION['success'] = "用户 '$username' 创建成功";
} catch (Exception $e) {
    $pdo->rollBack();
    $_SESSION['error'] = $e->getMessage();
}

header("Location: user_management.php");
exit;
